@@ -13,10 +13,24 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #include "ProgressDialog.h"
 
+// KDE 
 #include <kapplication.h>
 #include <klocale.h>
 
@@ -44,9 +58,9 @@ void ProgressDialog::init( int numOfFiles )
 	reset();
 }
 
-void ProgressDialog::print(QString in, QString out)
+void ProgressDialog::print(const QString& in, const QString& out) 
 {
-    setLabelText(in+(out==""?(QString)"->\n"+out:(QString)""));
+    setLabelText(in+(out.isEmpty()?(QString)"->\n"+out:(QString)""));
     return;
 }
 
