@@ -13,52 +13,74 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #ifndef __DESCRIBEALBUM_H__
 #define __DESCRIBEALBUM_H__
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+// Local 
 #include "imagefileinfo.h"
 
+// Qt 
 #include <qvariant.h>
-#include <kdialog.h>
 
-class QVBoxLayout; 
-class QHBoxLayout; 
-class QGridLayout; 
-class QGroupBox;
+// KDE 
+#include <kdialogbase.h>
+
+class QVBoxLayout;
+class QHBoxLayout;
+class QGridLayout;
+class QSpacerItem;
 class QLabel;
-class QLineEdit;
-class QMultiLineEdit;
-class QPushButton;
+class KLineEdit;
+class QGroupBox;
+class KTextEdit;
 
 class ImageFileInfo;
 
 
-class DescribeAlbum : public KDialog
+class DescribeAlbum : public KDialogBase
 { 
 	Q_OBJECT
 
 public:
-	DescribeAlbum( QWidget* parent, QString dirname, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+	DescribeAlbum( QWidget* parent,  const QString& dirname, const char* name = 0 );
 	~DescribeAlbum();
 
 protected slots:
-	void accept();
+	void slotOk();
     
 protected:
 	ImageFileInfo *iinfo;
 
-	QHBoxLayout* Layout1;
-	QGroupBox* GroupBox2;
-	QLabel* TextLabel2_2;
-	QLabel* TextLabel6;
-	QLineEdit* shortDescr;
-	QMultiLineEdit* longDescr;
-	QLabel* TextLabel1;
-	QLineEdit* title;
-	QPushButton* okButton;
-	QPushButton* cancelButton;
+    QLabel* textLabel1;
+    KLineEdit* title;
+    QGroupBox* DescribeAlbumgroupBox1;
+    QLabel* textLabel2;
+    KLineEdit* shortDescr;
+    QLabel* textLabel2_2;
+    KTextEdit* longDescr;
+
+    QVBoxLayout* DescribeAlbumLayout;
+    QHBoxLayout* DescribeAlbumlayout1;
+    QVBoxLayout* DescribeAlbumgroupBox1Layout;
 
 };
 
