@@ -13,11 +13,24 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
-
 #include "directory.h"
 
+// Local 
 #include "directoryview.h"
 #include "imageviewer.h"
 #include "imagefileiconitem.h"
@@ -33,6 +46,7 @@
 
 #include <unistd.h>
 
+// Qt 
 #include <qlistview.h>
 #include <qstring.h>
 #include <qdir.h>
@@ -40,23 +54,30 @@
 #include <qfileinfo.h>
 #include <qpixmapcache.h>
 
+// KDE 
 #include <kio/job.h>
 #include <kiconloader.h>
 #include <klineeditdlg.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kapplication.h>
+#ifndef Q_WS_WIN
 #include <konq_operations.h>
+#endif
+
+#define MYDEBUG kdDebug()<<__FILE__<<" " <<__LINE__ << " " << __FUNCTION__ << " "
 
 Directory::Directory( DirectoryView* parent,
-			 ImageViewer *iv,  ImageListView *imageList, MainWindow *mw )
+			 ImageViewer *iv,  
+			 ImageListView *imageList, 
+			 MainWindow *mw )
 	: ListItem(parent, iv, imageList, mw)
 {
 	full=( "/" );
 	init();
 }
 
-Directory::Directory(Directory* parent, QString filename ,
+Directory::Directory(Directory* parent, const QString& filename ,
 			DirectoryView* dirView, ImageViewer *iv, ImageListView  *imageList, MainWindow *mw )
 	: ListItem(parent, filename, dirView, iv, imageList, mw)
 {
@@ -74,24 +95,34 @@ void
 Directory::init()
 {
 	readable = TRUE;
-	setPixmap(0, BarIcon(KMimeType::iconForURL(full), KIcon::SizeSmall ));
+	setPixmap(0, BarIcon(KMimeType::iconForURL(getURL()), dirView->getIconSize() ));
 	setDropEnabled(true);
 	size=-1;
+	setType("Directory");
+	setReadOnly(FALSE);
+	loaded=false;
 }
 
 
 ListItem*
-Directory::find(QString dir)
+Directory::find(const QString& dir_)
 {
-	ListItem* dirt;
-	dirt=firstChild();
-	while(dirt != 0)
+	QString dir(dir_);
+	while(dir.startsWith("/")) dir = dir.right(dir.length()-1);
+	QStringList list = QStringList::split( "/", dir);
+	QString dirName = list[0];
+	ListItem* dirt = firstChild();
+	while(dirt)
 	{
-		if(QString(dir) == dirt->text(0)) break;
+		if(dirName == dirt->text(0)) break;
 		dirt = dirt->nextSibling ();
 	}
-	if(dirt) return dirt;
-	return NULL;
+	if(dirt) 
+		if(list.count()==1) 
+			return dirt;
+		else
+			return dirt->find(dir.right(dir.length()-dir.find("/")-1));
+	return dirt;
 }
 
 void 
@@ -110,8 +141,7 @@ Directory::recursivelyOpen()
 void
 Directory::setOpen( bool o )
 {
-//	kdDebug() << __FILE__ << __LINE__ << " begin Directory::setOpen( bool o ) " << o << " " << fullName() << endl;
-	if ( !isOpen() && o && !childCount() )
+	if ( !isOpen() && o && !childCount() && !loaded)
 	{
 		KApplication::setOverrideCursor( waitCursor ); // this might take time
 		
@@ -138,7 +168,7 @@ Directory::setOpen( bool o )
 		 		  	    	  (void)new Directory( this, f->fileName(), dirView, iv, imageList, mw);
 		 		  	  else
 		 		  	  {
-		 		  	   	   if ( Extract::canExtract(f->fileName()))
+		 		  	   	   if ( Extract::canExtract(f->absFilePath()))
 		 		  	   	   	(void)new CompressedFileItem(this, f->fileName(), fullName(),  mw, dirView, iv, imageList);
 		 		  	   	   else if(QFileInfo(f->fileName()).extension().lower() == "sia")				   
 		 		  	   	   	(void)new Album(this, f->fileName(), dirView, iv, imageList, mw);
@@ -151,56 +181,42 @@ Directory::setOpen( bool o )
 		KApplication::restoreOverrideCursor();      // restore original cursor
 
 		dirView->startWatchDir(fullName());
+		loaded=true;
 	}
 	else
 	if(!o && childCount() )
 	{
-		QListViewItem *dirt=firstChild(), *oldDir;
-		while(dirt != 0)
-		{
-			if(dirt->isSelected()) dirt->setSelected(false);
-			dirt->setOpen(false);
-			oldDir = dirt;
-			dirt = dirt->nextSibling ();
-			delete(oldDir);
-		}
-		dirView->stopWatchDir(fullName());
 	}
 
 	if ( o )
 	{
-		if(KMimeType::iconForURL(full )== "folder")
-			setPixmap( 0, SmallIcon("folder_open") );
+		if(KMimeType::iconForURL(getURL())== "folder")
+		{
+			setPixmap(0, BarIcon("folder_open", dirView->getIconSize() ));
+		}
 	}
 	else
 	{
-		setPixmap( 0, SmallIcon(KMimeType::iconForURL(full)) );
+		setPixmap(0, BarIcon(KMimeType::iconForURL(getURL()), dirView->getIconSize() ));
 	}
 
 	QListViewItem::setOpen( o );
 	repaint();
 	listView()->setUpdatesEnabled( TRUE );
-//	kdDebug() << __FILE__ << __LINE__ << " end Directory::setOpen( bool o ) " << o << " " << fullName() << endl;
 }
 
 
 bool
 Directory::refresh(bool )
 {
-//	kdDebug() << __FILE__ << __LINE__ << " begin Directory::refresh(bool ) "  << fullName() << endl;
 	QString s( fullName() );
 	QDir thisDir( s );
 	bool isS=isSelected();
-
-	if(!isS)
-	{
-		thisDir.setFilter(QDir::Dirs);
-	}
-	else
-	{
-		thisDir.setFilter(dirView->filter() | QDir::Dirs);
-	}
-	const QFileInfoList * files = thisDir.entryInfoList();
+	thisDir.setFilter(dirView->filter() | QDir::Dirs);
+	
+	const QFileInfoList * files = thisDir.entryInfoList();	
+	if (!files)
+		return false;
 	
 	//////////////////
 	QStringList after;
@@ -220,7 +236,10 @@ Directory::refresh(bool )
 			(f->isDir() && f->fileName()!=".")
 			||
 			(f->isFile () &&
-			(dirView->showAllFile() || dirView->isImage(f))))
+				(dirView->showAllFile() || 
+				 dirView->isImage(f) || 
+				 Extract::canExtract(f->absFilePath())))
+		)
 		{
 			item=imageList->findItem(f->fileName());
 			if(!item) news.append(f->fileName());
@@ -228,12 +247,11 @@ Directory::refresh(bool )
 		}
 	}
 
-//	kdDebug() << __FILE__ << __LINE__ << " \t Directory::refresh(bool ) "  << fullName() << endl;
+	QPoint tl(imageList->contentsX(), imageList->contentsY());
 
 	bool add=false, del=false;
 	for ( item=list.first();  item!= 0; item=list.next() )
 	{
-//		kdDebug() << __FILE__ << __LINE__ << " \t\t Directory::refresh(bool ) item->text()= " << fullName()+item->text() << endl;
 		if(!after.contains(item->text()))
 		{
 			deleted.append(item->text());
@@ -251,48 +269,51 @@ Directory::refresh(bool )
 		dirt = dirt->nextSibling ();
 	}
 
-//	kdDebug() << __FILE__ << __LINE__ << " \t Directory::refresh(bool ) "  << fullName() << endl;
-
+	int nbrAddedFiles=0;
 	///
 	for ( QStringList::Iterator it = news.begin(); it != news.end(); ++it )
 	{
-//		kdDebug() << __FILE__ << __LINE__ << " \t Directory::refresh(bool ) add " << fullName()+*it  << endl;
-		if(!QFileInfo(fullName()+*it).isDir ())
+		QFileInfo fi(fullName()+*it);
+		if(isS &&
+		  (dirView->isImage(&fi) ||
+		  (dirView->showAllFile() &&
+		  	(!fi.isDir() || Extract::canExtract(fi.absFilePath()))))
+		)
 		{
-//		kdDebug() << __FILE__ << __LINE__ << " \t\t Directory::refresh(bool ) add file " << fullName()+*it  << endl;
-			item= new ImageFileIconItem(imageList, this, *it, fullName(), iv);
+			item = new ImageFileIconItem(imageList, this, *it, fullName(), iv);
 			list.append(item);
-			mw->slotAddImage();
+			nbrAddedFiles++;
 			size++;
 			add=true;
 		}
-		else
-		if(QFileInfo(*it).fileName()!="." && !find(*it))
+		if(fi.fileName()!="." && !find(*it))
 		{
-//			kdDebug() << __FILE__ << __LINE__ << " \t\t Directory::refresh(bool ) add dir " << fullName()+*it  << endl;
-			if(QFileInfo(*it).fileName()!="..")
+			if(fi.isDir() && fi.fileName()!="..")
 			{
 				(void)new Directory(this, *it, dirView, iv, imageList, mw);
 				setExpandable( TRUE );
 			}
-			if(isS && dirView->showDir())
+			if(isS && fi.isDir() && dirView->showDir() )
 			{
-				item= new DirFileIconItem(imageList, this, *it, fullName(), iv);
+				item = new DirFileIconItem(imageList, this, *it, fullName(), iv);
 				list.append(item);
-				mw->slotAddImage();
+				nbrAddedFiles++;
 				size++;
 				add=true;
 			}
+			if (!fi.isDir() && Extract::canExtract(fi.absFilePath()))
+			{
+		 		(void)new CompressedFileItem(this, fi.fileName(), fullName(),  mw, dirView, iv, imageList);
+				setExpandable( TRUE );
+				setOpen(true);
+			}
 		}
 	}
-
-//	kdDebug() << __FILE__ << __LINE__ << " \t Directory::refresh(bool ) "  << fullName() << endl;
-	
 	int toDel=0;
 	for ( QStringList::Iterator it = deleted.begin(); it != deleted.end(); ++it )
 	{
-//		kdDebug() << __FILE__ << __LINE__ << " \t Directory::refresh(bool ) delete " << fullName()+*it  << endl;
-		if(QFileInfo(fullName()+*it).exists()) continue;
+		if(QFileInfo(fullName()+*it).exists())
+			continue;
 		dirView->removeDir(fullName()+*it);
 		if(isS)
 		{
@@ -304,34 +325,26 @@ Directory::refresh(bool )
 			}
 		}
 	}
-//	kdDebug() << __FILE__ << __LINE__ << " \t Directory::refresh(bool ) "  << fullName() << endl;
 	if(!del && !add) return false;
   
 	if(isOpen() && !childCount()) setExpandable( false );
 	if(isS)
 	{
-		size-=toDel;
+		size -= toDel;
 		mw->slotRemoveImage(toDel);
+		mw->slotAddImage(nbrAddedFiles);
 
-		QPoint tl(imageList->contentsX(), imageList->contentsY());
 		imageList->sort();
-		imageList->setContentsPos(tl.x(), tl.y());
+		imageList->ensureVisible(tl.x(), tl.y());
 	}
-	
-	
-	
-	//////////////////////////////////////////////////////////////////////
-//	thisDir.setNameFilter("*.sia");
-//	files = thisDir.entryInfoList();
-
-	kapp->processEvents();
-//	kdDebug() << __FILE__ << __LINE__ << " end Directory::refresh(bool )"   << endl;	
+	repaint();
 	return true;
 }
 
 void
-Directory::goTo(QString)
+Directory::goTo(const QString&)
 {
+	kdWarning()<<"Directory::goTo(const QString&) TODO"<<endl;
 }
 
 void
@@ -355,21 +368,25 @@ Directory::path()
 QString
 Directory::text( int column ) const
 {
-	if ( column == 0 )
+	if ( column == DirectoryView::COLUMN_NAME )
 		return f.name();
 	else
-	if(column == 2 )
+	if(column == DirectoryView::COLUMN_SIZE )
 	{
 		if(size>=0)
-			return  QString("%1").arg(size, 10);
+			return  QString("%1").arg(size);
 		else
 			return "";
 	}
 	else
-	if ( readable )
-		return i18n("Directory");
-	else
-		return i18n("Locked");
+	if(column == DirectoryView::COLUMN_TYPE)
+	{
+		if ( readable )
+			return i18n("Directory");
+		else
+			return i18n("Locked");
+	}
+	return "";
 }
 
 void
@@ -382,9 +399,7 @@ void
 Directory::removeImage(ImageFileIconItem *imf)
 {
 	if(!imf)
-	{
 		return;
-	}
 
 	if(list.find(imf)!=-1)
 	{
@@ -397,15 +412,14 @@ void
 Directory::unLoad()
 {
 	if(mw->preview()) imageList->stopLoading();
-	mw->slotRemoveImage(list.count());
-
+	mw->slotRemoveImage(size);
+	imageList->setUpdatesEnabled( FALSE ); 
 	for (FileIconItem *item = list.first(); item; item = list.next() )
 		delete(item);
 	list.clear();
 	iv->updateStatus();
+	imageList->setUpdatesEnabled( TRUE ); 
 	imageList->slotUpdate();
-	
-	//kapp->processEvents();
 }
 
 
@@ -413,15 +427,18 @@ void
 Directory::load(bool )
 {
 	bool hasIm=imageList->hasImages();
+
+	if(!imageList->hasImages()) { imageList->load(QString::null); imageList->setContentsPos(0,0); }
 	mw->setMessage(i18n("Loading directory %1...").arg(text(0)));
-	//KApplication::setOverrideCursor( waitCursor ); // this might take time
-	imageList->setUpdatesEnabled( FALSE );
+	KApplication::setOverrideCursor( waitCursor ); // this might take time
+	imageList->setUpdatesEnabled( FALSE ); 
 	imageList->stopLoading();
 
 	QString s( fullName() );
 	QDir thisDir( s );
 	thisDir.setFilter(dirView->filter());
 	const QFileInfoList * files = thisDir.entryInfoList();
+	
 	if ( files )
 	{
 		QFileInfoListIterator it( *files );
@@ -439,6 +456,7 @@ Directory::load(bool )
 					(!dirView->showAllFile() && dirView->isImage(f))))
 			{
 				item = new ImageFileIconItem(imageList, this, f->fileName(), fullName(), iv);
+				size+=(item->isImage()?1:0);
 			}
 			else
 			if(f->isDir() && f->fileName()!=".")
@@ -446,48 +464,46 @@ Directory::load(bool )
 				item = new DirFileIconItem(imageList, this, f->fileName(), fullName(), iv);
 			}
 
-			if(item)
-			{
-				list.append(item);
-				size++;
-			}
+			if(item) list.append(item);
 			item=NULL;
 		}
 		mw->slotAddImage(size);
 		imageList->sort();
-		repaint();//kapp->processEvents();
+		repaint();		
 		imageList->setUpdatesEnabled( TRUE );
-		if(!hasIm)
-		{
-			if(dirView->loadFirstImage())
-				imageList->first();
-			else        
-				iv->loadImage();
-		}
-		imageList->slotUpdate() ;
+		imageList->slotUpdate() ;				
+		
+		KApplication::restoreOverrideCursor();	// restore original cursor
+		repaint();kapp->processEvents();		
+		
+		
 		iv->updateStatus();
+		if(!hasIm && dirView->loadFirstImage()) imageList->first();
 		imageList->slotLoadFirst();
 	}
-	//KApplication::restoreOverrideCursor();	// restore original cursor
-
+	else
+	{
+		KApplication::restoreOverrideCursor();	// restore original cursor
+	}
 	mw->setMessage(i18n("Ready"));
-	//kapp->processEvents();
 }
 
 
 void
-Directory::createDir(QString dirName)
+Directory::createDir(const QString& dirName)
 {
-	KURL url = KURL("file://"+fullName()+dirName);
+#ifndef Q_WS_WIN
+	KURL url = KURL("file:"+fullName()+dirName);
 	KonqOperations::mkdir(mw, url);
 	setExpandable(true);
+#endif
 }
 
 void
-Directory::createAlbum(QString albumName)
+Directory::createAlbum(const QString& albumName)
 {
-	KURL urld = KURL("file://"+fullName()+albumName);
-	KURL urlo = KURL("file://"+KStandardDirs().findResource("templates",".source/TextFile.txt"));
+	KURL urld = KURL("file:"+fullName()+albumName);
+	KURL urlo = KURL("file:"+KStandardDirs().findResource("templates",".source/TextFile.txt"));
 	KIO::copy(urlo, urld, false);
 	setExpandable(true);
 	mw->addToBookmark(i18n("Albums"),fullName()+albumName);
@@ -498,29 +514,24 @@ Directory::createAlbum(QString albumName)
 void
 Directory::rename()
 {
-	kdDebug() << __FILE__ << __LINE__ << " begin  Directory::rename()" << endl;
-	if(newDirName!="")
+	if(!newDirName.isEmpty())
 	{	
 		f.setName(newDirName);
 		full=path()+"/"+newDirName+"/";
-		//mw->slotRefresh();
 		repaint();
 	}
-	kdDebug() << __FILE__ << __LINE__ << " end  irectory::rename()" << endl;
 }
 
 void
-Directory::rename(QString newDirName)
+Directory::rename(const QString& newDirName)
 {
-	kdDebug() << __FILE__ << __LINE__ << " begin  Directory::rename(QString newDirName="<< newDirName << endl;
-
 	this->newDirName=newDirName;
 
 	QString oldN=fullName();
 	QString newN=path()+"/"+newDirName;
 
-	KURL orgName = KURL("file://"+oldN);
-	KURL newName = KURL("file://"+newN);
+	KURL orgName = KURL("file:"+oldN);
+	KURL newName = KURL("file:"+newN);
 
 	KIO::SimpleJob *renameJob=KIO::rename(orgName, newName, true );
 	QObject::connect(renameJob, SIGNAL(result( KIO::Job *)),
@@ -528,9 +539,6 @@ Directory::rename(QString newDirName)
 
 	f.setName(newDirName);
 	updateChildren();
-	
-	kdDebug() << __FILE__ << __LINE__ << "  Directory::rename(QString newDirName) fullName()="<<  fullName() << " full=" << full << endl;
-	kdDebug() << __FILE__ << __LINE__ << " end  Directory::rename(QString newDirName="<< newDirName << endl;
 }
 
 
@@ -542,8 +550,6 @@ Directory::properties()
 void
 Directory::updateChildren()
 {
-	kdDebug() << __FILE__ << __LINE__ << " begin  updateChildren() de "<< fullName() << endl;
-	
 	ListItem::updateChildren();	
 	if(isSelected())
 	{
@@ -553,8 +559,6 @@ Directory::updateChildren()
 			item->setPath(fullName());
 		}
 	}
-	
-	kdDebug() << __FILE__ << __LINE__ << " end  updateChildren() de "<< fullName() << endl;
 }
 
 
