@@ -13,13 +13,32 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #ifndef __DIRECTORY_H__
 #define __DIRECTORY_H__
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+// Local 
 #include "listitem.h"
 
+// Qt 
 #include <qfile.h>
 #include <qptrlist.h>
 
@@ -39,7 +58,7 @@ class Directory:public ListItem
 {
 public:
 	Directory (DirectoryView* parent, ImageViewer * iv, ImageListView * imageList, MainWindow * mw);
-	Directory (Directory * parent, QString filename, DirectoryView* dirView, ImageViewer * iv,  ImageListView * imageList, MainWindow * mw);
+	Directory (Directory * parent, const QString& filename, DirectoryView* dirView, ImageViewer * iv,  ImageListView * imageList, MainWindow * mw);
 	~Directory();
 
 	QString text (int column) const;
@@ -55,15 +74,15 @@ public:
 	void unLoad ();
 	bool refresh(bool preview=true);
 
-	virtual ListItem *find (QString);
-	void goTo (QString dest);
+	virtual ListItem *find (const QString&);
+	void goTo (const QString& dest);
 	void loadFirst ();
 
 	void removeImage (ImageFileIconItem * imf);
 
-	void createDir(QString dirName);
-	void createAlbum(QString albumName);
-	void rename(QString newDirName);
+	void createDir(const QString& dirName);
+	void createAlbum(const QString& albumName);
+	void rename(const QString& newDirName);
 	void rename();
 	void updateChildren();
 	
@@ -73,6 +92,7 @@ protected:
 	void init();
 
 private:
+	bool loaded;
 	bool readable;
 	int size;
 	
