@@ -13,25 +13,39 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
-
 #include "directoryview.h"
 
+// Local
 #include "describeAlbum.h"
 #include "directory.h"
-#include "replace.h"
 #include "imageviewer.h"
 #include "imagefileiconitem.h"
 #include "compressedimagefileiconitem.h"
 #include "imagelistview.h"
 #include "mainwindow.h"
 #include "album.h"
+#include "listitem.h"
+#include "cdarchivecreatordialog.h"
+#ifdef HAVE_KIPI
+#include "kipiplugins/kipipluginmanager.h"
+#endif /* HAVE_KIPI */
 
-#ifdef HAVE_LIBDIGIKAM
-#include <digikam/albuminfo.h>
-#endif
-
+// Qt
 #include <qstring.h>
 #include <qfile.h>
 #include <qptrlist.h>
@@ -46,7 +60,9 @@
 #include <qdir.h>
 #include <qclipboard.h>
 #include <qpopupmenu.h>
+#include <qheader.h>
 
+// KDE
 #include <kurlrequesterdlg.h>
 #include <kio/job.h>
 #include <kio/jobclasses.h>
@@ -62,14 +78,23 @@
 #include <kapplication.h>
 #include <kaction.h>
 #include <kpopupmenu.h>
+#ifndef Q_WS_WIN
 #include <konq_operations.h>
+#endif
 #include <kurldrag.h>
 #include <kimageio.h>
+#include <kmimetype.h>
+#if  KDE_VERSION >= 0x30200
+#include <kinputdialog.h>
+#endif
 
-DirectoryView::DirectoryView (QWidget * parent, ImageViewer * iv, ImageListView* imageList, MainWindow * mw)
-:KListView (parent, "DirectoryView")
+
+#define MYDEBUG kdDebug()<<__FILE__<<" " <<__LINE__ << " " << __FUNCTION__ << " "
+
+DirectoryView::DirectoryView (QWidget * parent, ImageViewer * iv,
+	ImageListView* imageList, MainWindow * mw)
+	:KListView (parent, "DirectoryView")
 {
-
 	this->iv = iv;
 	this->imageList = imageList;
 	this->mw = mw;
@@ -77,21 +102,32 @@ DirectoryView::DirectoryView (QWidget * parent, ImageViewer * iv, ImageListView*
 	addColumn (i18n("Name"));
 	addColumn (i18n("Type"));
 	addColumn (i18n("Size"));
+	addColumn (" ");
 
-	setColumnAlignment( 1, Qt::AlignLeft );
-	setColumnAlignment( 2, Qt::AlignRight );
+	setColumnAlignment( COLUMN_TYPE, Qt::AlignLeft );
+	setColumnAlignment( COLUMN_SIZE, Qt::AlignRight );
 
-	setAllColumnsShowFocus(true);
-	setShowSortIndicator(true);
-	setFullWidth(true);
-	setResizeMode( KListView::LastColumn );
-	setShowToolTips(true);
-	setSelectionModeExt (KListView::Extended);
 	setAcceptDrops (true);
-	clearWState( WState_Polished );
+	setAllColumnsShowFocus(true);
+	setShowToolTips(true);
+	setShowSortIndicator(true);
+	setSelectionModeExt (KListView::Extended);
 
-	setSorting (1);
+	setFullWidth(true);
+
+	header()->setClickEnabled(FALSE, COLUMN_SELECT);
+	header()->setStretchEnabled(true, COLUMN_NAME);
+	header()->setMovingEnabled ( false );
+
+	setColumnWidthMode (COLUMN_SELECT, Manual );
+	setColumnWidth(COLUMN_SELECT, 3*ListItem::TREE_CHECKBOX_MAXSIZE/2);
+	header()->setResizeEnabled (false, COLUMN_SELECT );
+
+	setSorting (COLUMN_TYPE);
 	sort();
+	setColumnWidthMode (COLUMN_TYPE, Manual );
+	//hideColumn ( COLUMN_TYPE ) ;
+	setColumnWidth (COLUMN_TYPE, 0 );
 
 	setShowHiddenDir(false);
 	dropping = false;
@@ -111,28 +147,36 @@ DirectoryView::DirectoryView (QWidget * parent, ImageViewer * iv, ImageListView*
 	connect (autoopen_timer, SIGNAL (timeout ()),
 			this, SLOT (openFolder ()));
 
-	copyProgress=new QProgressDialog (mw, "copyProgress", true);
-
+	//////////////
 	dirWatch = new KDirWatch();
+#ifndef SHOWIMG_NO_CDARCHIVE
+	dirWatch->addDir(QDir::homeDirPath()+"/.showimg/cdarchive/");
+#endif
 	connect(dirWatch, SIGNAL(dirty (const QString&)),
 			mw, SLOT(slotDirChange(const QString&)));
+	connect(dirWatch, SIGNAL(created (const QString&)),
+			mw, SLOT(slotDirChange_created(const QString&)));
+	connect(dirWatch, SIGNAL(deleted (const QString&)),
+			mw, SLOT(slotDirChange_deleted(const QString&)));
 	startWatchDir();
 
-	connect(this, SIGNAL(selectionChanged ()),
-			SLOT(slotSelectionChanged ()));
+	///
+	connect(this, SIGNAL(selectionChanged ()), SLOT(slotSelectionChanged ()));
 }
 
 
+DirectoryView::~DirectoryView()
+{
+}
+
 void
 DirectoryView::initMenu(KActionCollection *actionCollection)
 {
 	this->actionCollection=actionCollection;
 
-	popup = new QPopupMenu();
-	KPopupMenu *popupnew = new KPopupMenu ();
-		actionCollection->action("editdirnew")->plug(popupnew);
-		actionCollection->action("editalbumnew")->plug(popupnew);
-	popup->insertItem(i18n("Create &New"), popupnew);
+	popup = new KPopupMenu();
+		popup->insertTitle("", 1);
+	actionCollection->action("create_new_items")->plug(popup);
 	actionCollection->action("dirRecOpen")->plug(popup);
 	popup->insertSeparator();
 	actionCollection->action("editdircopy")->plug(popup);
@@ -149,41 +193,33 @@ DirectoryView::initMenu(KActionCollection *actionCollection)
 
 
 ListItem*
-DirectoryView::getDir(QString dirfullname)
+DirectoryView::getDir(const QString& path)
 {
-	QString res(dirfullname);
-	if(res[res.length()-1]=='/')
-		res = res.left(res.length()-1);
-
-	int pos = res.find ("/");
 	ListItem *ssrep;
-	res = res.right(res.length () - pos - 1);
-	pos = res.find ("/");
-	ssrep = (Directory*)firstChild();
-
-	while (pos != -1 && ssrep!=NULL)
+	ListItem *rootItems = firstChild ();
+	while(rootItems)
 	{
-		ssrep = ssrep->find (res.left (pos));
-		res =res.right(res.length () - pos - 1);
-		if (ssrep)
-			pos = res.find ("/");
-		else
-			break;
+		if(path.startsWith(rootItems->fullName()))
+		{
+			ssrep = rootItems->find(path);
+			if (ssrep)
+			{
+				return ssrep;
+			}
+		}
+		rootItems = rootItems->nextSibling();
 	}
-	if(!res.isEmpty() && ssrep)
-		ssrep = ssrep->find(res);
-
-	return ssrep;
+	return NULL;
 }
 
 void
-DirectoryView::removeDir(QString dirfullname)
+DirectoryView::removeDir(const QString& dirfullname)
 {
 	ListItem * item = getDir(dirfullname);
 	if(item)
 	{
-		if(item->isSelected()) mw->goUp();
-		delete(getDir(dirfullname));
+		if(item->isSelected()) item->unLoad();
+		delete(item);
 	}
 }
 
@@ -193,7 +229,7 @@ DirectoryView::slotDirInfo()
 {
 	if(clickedItem)
 	{
-		   DescribeAlbum(mw, ((Directory*)clickedItem)->fullName(), "IDirInfo", true).exec();
+		   (void)DescribeAlbum(mw, clickedItem->fullName()).exec();
 	}
 }
 
@@ -203,15 +239,17 @@ DirectoryView::slotDirProperty()
 	if(clickedItem)
 	{
 		KApplication::setOverrideCursor (waitCursor);
-		//KFileItem *item = new KFileItem(( ((ListItem*)clickedItem)->getURL()), KFileItem::Unknown/*"inode/directory"*/, S_IFDIR);        	
-		KFileItem *item = new KFileItem(KFileItem::Unknown, KFileItem::Unknown, 
-				(((ListItem*)clickedItem)->getURL()), true);
-        	KPropertiesDialog *prop	= new KPropertiesDialog( item,
+		KFileItem *item = new KFileItem(KFileItem::Unknown,
+				KFileItem::Unknown,
+				clickedItem->getURL(),
+				true);
+        	KPropertiesDialog prop( item,
 			mw->iv, "KPropertiesDialog",
 			true, false);
 
 		KApplication::restoreOverrideCursor ();
-		prop->exec();
+		prop.exec();
+		delete(item);
 	}
 }
 
@@ -230,14 +268,29 @@ DirectoryView::slotShowItem (QListViewItem * item)
 void
 DirectoryView::startWatchDir(QString dir)
 {
+	if(dirWatch->contains(dir)) return;
+	
 	dirWatch->stopScan();
-	dirWatch->addDir(dir);
+	QFileInfo info(dir);
+	if(info.isDir())
+	{
+		dirWatch->addDir(dir);
+	}
+	else
+	if(info.isFile())
+	{
+		dirWatch->addFile(dir);
+	}
 	dirWatch->startScan();
 }
 
 void DirectoryView::stopWatchDir(QString dir)
 {
-	dirWatch->removeDir(dir);
+	if(QFileInfo(dir).isDir())
+		dirWatch->removeDir(dir);
+	else
+	if(QFileInfo(dir).isFile())
+		dirWatch->removeFile(dir);
 }
 
 void
@@ -247,7 +300,6 @@ DirectoryView::startWatchDir()
 }
 
 
-
 void
 DirectoryView::stopWatchDir()
 {
@@ -258,23 +310,28 @@ DirectoryView::stopWatchDir()
 void
 DirectoryView::updateActions(ListItem *item)
 {
-	if(!item) return;
-
-	bool enableAction;
+	if(!item)
+	{
+		imageList->load(NULL);
+		return;
+	}
+	bool enableAction=true;
 	if(item->text (1) != i18n("Directory"))
-	{
 		enableAction=false;
-	}
-	else
-	{
-		enableAction=true;
-	}
 	actionCollection->action("editpaste")->setEnabled(enableAction);
 	actionCollection->action("editdirnew")->setEnabled(enableAction);
 	actionCollection->action("editalbumnew")->setEnabled(enableAction);
 	actionCollection->action("dirRecOpen")->setEnabled(enableAction);
 	actionCollection->action("editdircopy")->setEnabled(enableAction);
+
+	enableAction = !item->isReadOnly();
 	actionCollection->action("editdirmove")->setEnabled(enableAction);
+	actionCollection->action("editdirrename")->setEnabled(enableAction);
+	actionCollection->action("editdirtrash")->setEnabled(enableAction);
+	actionCollection->action("editdirdelete")->setEnabled(enableAction);
+	actionCollection->action("editdirpaste files")->setEnabled(enableAction);
+	actionCollection->action("Dir Info")->setEnabled(enableAction);
+
 }
 
 
@@ -282,19 +339,11 @@ void
 DirectoryView::slotSelectionChanged ()
 {
 	if(isDropping()) return;
-
-//	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::selectionChanged ()"   << endl;
-	updateActions((ListItem*)currentItem());
-
-#ifdef HAVE_LIBDIGIKAM
-	mAlbumMan = Digikam::AlbumManager::instance();
-	mAlbumMan->setLibraryPath( ((ListItem*)currentItem())->path());
-
-	Digikam::AlbumInfo *album = mAlbumMan->findAlbum(((ListItem*)currentItem())->name());
-	if(!album) album = new Digikam::AlbumInfo(mAlbumMan, ((ListItem*)currentItem())->name());
-	mAlbumMan->setCurrentAlbum(album);
+	updateActions(currentItem());
+	if(!imageList->hasImageSelected()) imageList->load(NULL);
+#ifdef HAVE_KIPI
+	mw->pluginManager()->currentAlbumChanged(currentItem()->fullName());
 #endif
-//	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::selectionChanged ()"   << endl;
 }
 
 
@@ -303,12 +352,11 @@ void
 DirectoryView::contentsDragEnterEvent (QDragEnterEvent * event)
 {
 	dropping = true;
-	setSelectionMode (QListView::Single);
-	oldCurrent = selectedItem ();
+	initSelectedListItem();
 	if (QTextDrag::canDecode (event))
 	{
 		event->acceptAction ();
-		QListViewItem *i = itemAt (contentsToViewport (event->pos ()));
+		ListItem *i = itemAt (contentsToViewport (event->pos ()));
 		if (i)
 		{
 			dropItem = i;
@@ -321,11 +369,7 @@ void
 DirectoryView::contentsDragLeaveEvent (QDragLeaveEvent *)
 {
 	autoopen_timer->stop ();
-	dropItem = NULL;
-	setMultiSelection (false);
-	setCurrentItem (oldCurrent);
-	setSelected (oldCurrent, TRUE);
-	setSelectionMode (QListView::Extended);
+	restoreSelectedListItem();
 	dropping = false;
 }
 
@@ -341,7 +385,7 @@ DirectoryView::contentsDragMoveEvent (QDragMoveEvent * e)
 		return;
 	}
 
-	QListViewItem *i = itemAt (contentsToViewport ( e->pos ()));
+	ListItem *i = itemAt (contentsToViewport ( e->pos ()));
 	if (i)
 	{
 		setSelected (i, TRUE);
@@ -365,11 +409,9 @@ DirectoryView::contentsDragMoveEvent (QDragMoveEvent * e)
 void
 DirectoryView::contentsDropEvent (QDropEvent * event)
 {
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::contentsDropEvent (QDropEvent * event)"  << endl;
 	autoopen_timer->stop ();
-	setSelected (dropItem, false);
 
-	if ( !QUriDrag::canDecode(event) )
+	if ( !QUriDrag::canDecode(event) || !dropItem)
 	{
 		event->ignore();
 	}
@@ -383,303 +425,125 @@ DirectoryView::contentsDropEvent (QDropEvent * event)
 
 		if (QUriDrag::decode (event, lst))
 		{
-			qWarning("%s %d DirectoryView::contentsDropEvent (QDropEvent * event)",__FILE__,__LINE__);
-			if (((ListItem*) dropItem)->text (1) == i18n("Album"))
-			{
+			event->acceptAction();
+			if (dropItem->text(1) == i18n("Album"))
 				((Album*)dropItem)->addURL(QStringList::fromStrList(lst));
-			}
 			else
-			if (((ListItem*) dropItem)->text (1) != i18n("Directory"))
+			if (dropItem->text(1) != i18n("Directory"))
 			{
-				dropItem = NULL;
-				KMessageBox::error (this, i18n("Adding file in an archive is not yet implemented"), i18n("File(s) copy/move"));
+				KMessageBox::error (this,
+						"<qt>"+i18n("Adding file in '%1' is not yet implemented")
+							.arg(((ListItem*) dropItem)->text (1))+"</qt>",
+					 	i18n("File(s) Copy/Move"));
 			}
 			else
 			if(!QFileInfo(((Directory*)dropItem)->fullName()).isWritable ())
 			{
-				dropItem = NULL;
-				KMessageBox::error (this, i18n("The destination directory is not writable"), i18n("File(s) copy/move"));
+				KMessageBox::error (this,
+						i18n("The destination directory is not writable"),
+						i18n("File(s) Copy/Move"));
 			}
 			else
 			switch (event->action ())
 			{
+
+
 				case QDropEvent::Copy:
 				case QDropEvent::Move:
 				{
-					if(!dropItem)
-					{
-						qWarning("%s %d ERROR dropItem est null !!!", __FILE__,__LINE__);
-		    				return;
-					}
-					destDir=new QString( ((Directory*)dropItem)->fullName());
+					bool canBeMoved = true;
+					if(event->source() == imageList)
+						canBeMoved = imageList->currentDragItemAreMovable();
 
-					event->acceptAction();
+					destDir=new QString( ((ListItem*)dropItem)->fullName());
 					contentsDragLeaveEvent(NULL);
-
-					if (event->action () == QDropEvent::Move)
-					{
+					if (event->action () == QDropEvent::Move && canBeMoved )
 						move(QStringList::fromStrList(lst), *destDir);
-					}
 					else
-					{
 						copy(QStringList::fromStrList(lst), *destDir);
-					}
 				}
 		 		return;
 		 		default:return;
 			}
 		}
 	}
-
-	setCurrentItem (oldCurrent);
-	setSelected (oldCurrent, TRUE);
-
+	restoreSelectedListItem();
 	dropping = false;
-	setSelectionMode (QListView::Extended);
-
 }
 
 
 QString
-DirectoryView::getDestName(QString orgFile, QString destDir)
+DirectoryView::getDestName(const QString& /*orgFile*/, const QString& /*destDir*/)
 {
-	QString fdest(destDir);
-
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::getDestName(QString orgFile, QString destDir) : " << orgFile <<" " << fdest << endl;
-	if(replaceAll)
-	{
-		return  fdest;
-	}
-	else
-	{
-	ConfirmReplace cr(copyProgress, "ConfirmReplace", orgFile, fdest);
-	switch (cr.exec())
-	{
-		case 1 : /*Replace()*/
-			return fdest;
-           	        break;
-
-		case 2 : /*slotSkip*/
-			autoSkip=true;
-			return NULL;
-			break;
-
-		case 3 :/*slotReplaceAll*/
-			replaceAll=true;
-			return fdest;
-			break;
-
-		case 4 : /*slotCancel*/
-			setMultiSelection (false);
-			clearSelection ();
-
-			setCurrentItem (oldCurrent);
-			setSelected (oldCurrent, TRUE);
-
-			setSelectionMode (QListView::Extended);
-			dropping = false;
-
-			currentOperation=NONE;
-
-		        return QString();
-			break;
-
-		case 5 : /*slotRename*/
-			return cr.getRename();
-			break;
-		}
-	}
-
-	return fdest;
+	return QString::null;
 }
 
 void
 DirectoryView::copyNext()
 {
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::copyNext()"   << endl;
-/*
-	if(!fileToProcess->isEmpty())
-	{
-		copyProgress->setProgress(totalFiles-fileToProcess->count());
-		QString *dest=getDestName(fileToProcess->first());
-
-		if(dest)
-		{
-			copyProgress->setProgress(totalFiles-fileToProcess->count());
-			copyProgress->setLabelText(i18n("Copy <b>`%1'</b>").arg(shrinkdn(*dest)));
-		}
-
-		while( (dest==NULL) && (!fileToProcess->isEmpty()) && (currentOperation!=NONE))
-		{
-			fileToProcess->removeFirst();
-			if(!fileToProcess->isEmpty()) dest=getDestName(fileToProcess->first());
-		}
-		if(!fileToProcess->isEmpty())
-		{
-			if(currentOperation!=NONE)
-			{
-				QString *org=fileToProcess->first();
-				copy(org, dest);
-			}
-		}
-		else
-		{
-			currentOperation=NONE;
-		}
-	}
-	else
-	{
-		currentOperation=NONE;
-	}
-
-	if(currentOperation==NONE)
-	{
-		currentOperation=NONE;
-		delete(fileToProcess); fileToProcess=NULL;
-
-		autoSkip=false;
-  		replaceAll=false;
-
-		copyProgress->setProgress(copyProgress->totalSteps());
-		copyProgress->hide();
-		delete(copyProgress);
-
-		currentItemName=QString();
-
-		delete(destDir); destDir=NULL;
-
-		dropping = false;
-		setSelectionMode (QListView::Extended);
-
-		mw->slotRefresh();
-		imageList->slotLoadFirst();
-	}
-	*/
+	kdWarning() << __FILE__ << __LINE__ << " DirectoryView::copyNext()"   << endl;
 }
 
 void
 DirectoryView:: moveNext()
 {
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::moveNext()"   << endl;
-/*
-	if(!fileToProcess->isEmpty())
-	{
-		QString *dest=getDestName(fileToProcess->first());
-		if(dest)
-		{
-			copyProgress->setProgress(totalFiles-fileToProcess->count());
-			copyProgress->setLabelText(i18n("Move <b>`%1'</b>").arg(shrinkdn(*dest)));
-		}
-		while( (dest==NULL) && (!fileToProcess->isEmpty()) && (currentOperation!=NONE))
-		{
-			fileToProcess->removeFirst();
-			if(!fileToProcess->isEmpty()) dest=getDestName(fileToProcess->first());
-		}
-		if(!fileToProcess->isEmpty())
-		{
-			if(currentOperation!=NONE)
-			{
-				QString *org=fileToProcess->first();
-				int pos = org->findRev ("/");
-				const QString itfi(org->right (org->length () - (pos + 1)));
-				FileIconItem *fi = imageList->findItem (itfi);
-				if(fi)
-				{
-					FileIconItem *next=fi->nextItem();
-					if(next)
-						currentItemName=next->text();
-					else
-					{
-						next=fi->prevItem();
-						if(next)
-							currentItemName=next->text();
-						else
-							currentItemName=QString();
-					}
-				}
-				else
-					currentItemName=QString();
-				if(fi && !fi->isMovable())
-				{
-					copy(org, dest);
-				}
-				else
-				{
-					move(org, dest);
-				}
-			}
-		}
-		else
-		{
-			currentOperation=NONE;
-		}
-	}
-	else
-	{
-		currentOperation=NONE;
-	}
+	kdWarning() << __FILE__ << __LINE__ << " DirectoryView:: moveNext()"   << endl;
+}
 
-	if(currentOperation==NONE)
-	{
-		currentOperation=NONE;
-		delete(fileToProcess); fileToProcess=NULL;
-
-		autoSkip=false;
-  		replaceAll=false;
-
-		copyProgress->setProgress(copyProgress->totalSteps());
-		copyProgress->hide();
-		delete(copyProgress);
-
-		imageList->setCurrentItemName(currentItemName);
-
-		currentItemName=QString();
-
-		delete(destDir); destDir=NULL;
-
-		//
-		setCurrentItem (oldCurrent);
-		setSelected (oldCurrent, TRUE);
-
-		dropping = false;
-		setSelectionMode (QListView::Extended);
-
-		mw->slotRefresh();
-		imageList->slotLoadFirst();
-	}
-*/
+ListItem*
+DirectoryView::itemAt ( const QPoint & viewPos ) const
+{
+	return (ListItem*)KListView::itemAt(viewPos);
+}
+ListItem*
+DirectoryView::currentItem () const
+{
+	return (ListItem*)KListView::currentItem ();
+}
+ListItem*
+DirectoryView::firstChild() const
+{
+	return (ListItem*)KListView::firstChild ();
 }
 
 void
 DirectoryView::contentsMouseReleaseEvent(QMouseEvent* e)
 {
-	if (e->button () == RightButton)
+	if (e->button () == LeftButton)
 	{
-		clickedItem = itemAt(contentsToViewport(e->pos()));
-		if (clickedItem->text (1) == i18n("Directory"))
-		{
-			popup->exec(e->globalPos());
-		}
+		ListItem *item=itemAt(contentsToViewport(e->pos()));
+		if(item)
+			if(item->isSelected())
+				return;
 	}
+	KListView::contentsMouseReleaseEvent(e);
 }
 
+
 void
 DirectoryView::contentsMousePressEvent(QMouseEvent * e)
 {
 	if (e->button () == RightButton)
 	{
 		clickedItem = itemAt(contentsToViewport(e->pos()));
-		updateActions((ListItem*)clickedItem);
+		updateActions(clickedItem);
+		popup->changeTitle(1, clickedItem->text(0));
 		popup->exec(e->globalPos());
-		updateActions((ListItem*)currentItem());
 	}
-	else
-	if (e->button () == LeftButton)
-		QListView::contentsMousePressEvent (e);
-
 	else
 	if (e->button () == MidButton)
 		contentsMouseDoubleClickEvent(e);
+	else
+	if (e->button () == LeftButton)
+	{
+		if(header()->sectionAt(e->x())!=3)
+			KListView::contentsMousePressEvent (e);
+		else
+		{
+			ListItem *item = itemAt(contentsToViewport(e->pos()));
+			setSelected(item, !item->isSelected());
+		}
+	}
 
 }
 
@@ -695,10 +559,16 @@ DirectoryView::contentsMouseDoubleClickEvent ( QMouseEvent * e )
 		item->setOpen(true);
 }
 
+void
+DirectoryView::contentsMouseMoveEvent ( QMouseEvent * e )
+{
+	if(e->state () != LeftButton)
+		KListView::contentsMouseMoveEvent(e);
+}
+
 void
 DirectoryView::copyingDirDone( KIO::Job *job)
 {
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::copyingDirDone( KIO::Job *job)"   << endl;
 	if(job->error()==0)
 	{
 		//pas d'erreurs
@@ -730,7 +600,7 @@ DirectoryView::copyingDirDone( KIO::Job *job)
 	else
 	{
 		//erreur
-		job->showErrorDialog(copyProgress);
+		job->showErrorDialog(mw);
 	}
 
 }
@@ -738,53 +608,20 @@ DirectoryView::copyingDirDone( KIO::Job *job)
 void
 DirectoryView::movingDirDone( KIO::Job *job)
 {
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::movingDirDone( KIO::Job *job)"   << endl;
 	if(job->error()==0)
 	{
 		//pas d'erreurs
-		ListItem* dest=getDir(dirDest);
-		if(dest)
-		{
-			if(!dest->isOpen())
-			{
-				//rien a faire
-			}
-			else
-			{
-				QString name=QDir(dirOrg).dirName();
-				if(!getDir(dirDest+name))
-				{
-					//ajout du rep
-					if(dest->text(1)==i18n("Directory"))
-					{
-						(void)new Directory( (Directory*)dest, name, this, iv, imageList, mw);
-					}
-					dest->setExpandable(true);
-				}
-			}
-		}
-		else
-		{
-		}
-		ListItem *d = getDir(dirOrg);
-		if(d)
-		{
-			d->setOpen(false);
-			d->setSelected(false);
-			delete(d);
-		}
 	}
 	else
 	{
 		//erreur
-		job->showErrorDialog(copyProgress);
+		job->showErrorDialog(mw);
 	}
 }
 
 void
 DirectoryView::copyingDone( KIO::Job *job)
 {
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::copyingDone( KIO::Job *job)"   << endl;
 	if(job->error()==0)
 	{
 		//pas d'erreurs
@@ -794,44 +631,27 @@ DirectoryView::copyingDone( KIO::Job *job)
 		//erreur
 		job->showErrorDialog();
 	}
-	fileToProcess->removeFirst();
-
-	if(currentOperation==COPY)
-		copyNext();
-	else
-		moveNext();
 }
 
 void
 DirectoryView::movingDone( KIO::Job *job )
 {
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::movingDone( KIO::Job *job )"   << endl;
 	if(job->error()==0)
 	{
-
+		//pas d'erreurs
+		mw->slotRefresh();
 	}
 	else
 	{
 		//erreur
-		kdDebug() << __FILE__ << __LINE__ << " DirectoryView::movingDone( KIO::Job *job )"<< endl;
 		job->showErrorDialog();
 	}
-	fileToProcess->removeFirst();
-
-	if(currentOperation==MOVE)
-		moveNext();
-	else
-		copyNext();
 }
 
 bool
 DirectoryView::copy (QString *dep, QString *dest)
 {
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::copy (QString *dep, QString *dest)"   << endl;
-	KURL urldep,urldest;
-	urldep.setPath(*dep);
-	urldest.setPath(*dest);
-	KonqOperations::copy( mw, KonqOperations::COPY, urldep,  urldest);
+	copy(QStringList(*dep), *dest);
 	return true;
 }
 
@@ -839,133 +659,71 @@ DirectoryView::copy (QString *dep, QString *dest)
 bool
 DirectoryView::move (QString *dep, QString *dest)
 {
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::move (QString *dep, QString *dest)" << *dep << " " << *dest << endl;
-
-	KURL urldep,urldest;
-	urldep.setPath(*dep);
-	urldest.setPath(*dest);
-	KonqOperations::copy( mw, KonqOperations::MOVE, urldep,  urldest);
-
+	move(QStringList(*dep), *dest);
 	return true;
 }
 
 
 
 void
-DirectoryView::copy(QStringList uris, QString dest)
+DirectoryView::copy(const QStringList& uris, const QString& dest)
 {
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::copy (QStringList uris, QString dest)" <<  dest << endl;
-
+#ifndef Q_WS_WIN
 	if(!QFileInfo(dest).isDir())
 	{
-		 KMessageBox::error(mw->iv, "<qt>"+i18n("Unable to copy files into '%1' because it is not a directory.").arg(dest)+"</qt>", i18n("File(s) copy"));
+		 KMessageBox::error(mw->iv, "<qt>"
+		 	+i18n("Unable to copy files into '%1' because it is not a directory.").arg(dest)
+			+"</qt>",
+			i18n("File(s) Copy"));
 		 return;
 	}
-
-
-
-
-
-
-	////
-
-	if(!QFileInfo(QFileInfo(dest).dirPath()).isWritable())
-	{
-		 KMessageBox::error(mw->iv, "<qt>"+i18n("The directory '<b>%1</b>' is not writable").arg(shrinkdn(dest))+"</qt>");
-		 return;
-	}
-
-
-	//
-	QString fdest = dest;
-	QString orgFile = *uris.begin();
-	int pos = orgFile.findRev ("/");
-	fdest.append(orgFile.right(orgFile.length() - pos));
-	if (QDir(orgFile) == QDir(fdest))
-	{
-		KMessageBox::error (mw, "<qt>"+i18n("Unable to copy <b>%1</b> because the destination file is the same").arg(orgFile)+"</qt>", i18n("File(s) copy"));
-	}
-	//
-	QStringList listExist;
-	QStringList list;
-	for ( QStringList::Iterator it = uris.begin(); it != uris.end(); ++it ) {
-        	fdest = dest;
-		orgFile = *it;
-		pos = orgFile.findRev ("/");
-		fdest.append(orgFile.right(orgFile.length() - pos));
-
-		if (QFileInfo(fdest).isDir() && QFile(QFileInfo(fdest).dirPath(true)+"/"+QFileInfo(fdest).fileName()).exists())
-			listExist.append(*it);
-		else
-			list.append(*it);
-	}
-
-	//
 	KURL urldest;
 	urldest.setPath(dest);
 	//
-	/*
-	for ( QStringList::Iterator it = listExist.begin(); it != listExist.end(); ++it ) {
-        	fdest = dest;
-		orgFile = KURL(*it).path();
-		pos = orgFile.findRev ("/");
-		fdest.append(orgFile.right(orgFile.length() - pos-1));
-
-		QString rDest(getDestName(orgFile, fdest));
-
-		kdDebug() << __FILE__ << __LINE__ << " DirectoryView::copy(QStringList uris, QString dest) : " << orgFile <<" ->" << rDest << endl;
-		KIO::file_copy(KURL(rDest), urldest, -1, true);
-		kdDebug() << __FILE__ << __LINE__ << " DirectoryView::copy(QStringList uris, QString dest) : " << orgFile <<" ->" << rDest << endl;
-
+	KURL::List list;
+	QStringList _uris_=uris;
+	KURL url;
+	for ( QStringList::Iterator it = _uris_.begin(); it != _uris_.end(); ++it )
+	{
+		KURL tmp_url(*it);
+		url.setPath(tmp_url.path());
+		list.append(url);
 	}
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::copy(QStringList uris, QString dest)  " << endl;
-	*/
-	list += listExist;
-	KonqOperations::copy( mw, KonqOperations::COPY, KURL::List(list),  urldest);
-
-
-
+	KIO::CopyJob *job = KIO::copy(list, urldest);
+	connect(job, SIGNAL(result( KIO::Job *)),
+		this, SLOT(copyingDone( KIO::Job *)));
+#endif
 }
 
 
 void
-DirectoryView::move(QStringList uris, QString dest)
+DirectoryView::move(const QStringList& uris, const QString& dest)
 {
-	if(!QFileInfo(QFileInfo(dest).dirPath()).isWritable())
+#ifndef Q_WS_WIN
+	if(!QFileInfo(dest).isDir())
 	{
-		 KMessageBox::error(mw->iv, "<qt>"+i18n("The directory '<b>%1</b>' is not writable").arg(shrinkdn(dest))+"</qt>");
+		 KMessageBox::error(mw->iv, "<qt>"
+		 	+i18n("Unable to move files into '%1' because it is not a directory.").arg(dest)
+			+"</qt>",
+			i18n("File(s) Copy"));
 		 return;
 	}
-
 	KURL urldest;
 	urldest.setPath(dest);
-
 	//
-	QString fdest = dest;
-	QString orgFile = *uris.begin();
-	int pos = orgFile.findRev ("/");
-	fdest.append(orgFile.right(orgFile.length() - pos));
-	if (QDir(orgFile) == QDir(fdest))
+	KURL::List list;
+	QStringList _uris_=uris;
+	KURL url;
+	for ( QStringList::Iterator it = _uris_.begin(); it != _uris_.end(); ++it )
 	{
-		KMessageBox::error (mw, "<qt>"+i18n("Can't copy <b>%1</b> because the destination file is the same").arg(orgFile)+"</qt>", i18n("File(s) copy"));
+		KURL tmp_url(*it);
+		url.setPath(tmp_url.path());
+		list.append(url);
 	}
-	//
-	QStringList listExist;
-	QStringList list;
-	for ( QStringList::Iterator it = uris.begin(); it != uris.end(); ++it ) {
-        	fdest = dest;
-		orgFile = *it;
-		pos = orgFile.findRev ("/");
-		fdest.append(orgFile.right(orgFile.length() - pos));
-
-		if (QFile(QFileInfo(fdest).dirPath(true) + "/" + QFileInfo(fdest).fileName()).exists())
-			listExist.append(*it);
-		else
-			list.append(*it);
-	}
-
-	list += listExist;
-	KonqOperations::copy( mw, KonqOperations::MOVE, KURL::List(list),  urldest);
+	KIO::CopyJob *job = KIO::move(list, urldest);
+	connect(job, SIGNAL(result( KIO::Job *)),
+		this, SLOT(movingDone( KIO::Job *)));
+#endif
 }
 
 
@@ -984,12 +742,11 @@ DirectoryView::openFolder ()
 void
 DirectoryView::slotDirPasteFiles()
 {
-	kdDebug() << __FILE__ << __LINE__ << " DirectoryView::slotDirPasteFiles()"   << endl;
 	KURL::List uris;
 	if(KURLDrag::decode(KApplication::clipboard()->data(), uris))
 	{
 		if(!uris.isEmpty())
-			copy(uris.toStringList(), ((Directory*)clickedItem)->fullName());
+			copy(uris.toStringList(), clickedItem->fullName());
 	}
 
 }
@@ -1006,16 +763,24 @@ DirectoryView::slotRename ()
 void
 DirectoryView::slotRename (QListViewItem *item)
 {
-  if(!item) return;
+	if(!item) return;
+
 	ListItem *dir=(ListItem*)item;
 	QString fullname=dir->fullName();
 	QString name=dir->name();
 	bool ok;
+	#if  KDE_VERSION < 0x30200
 	const QString newName(KLineEditDlg::getText("<qt>"+i18n("Rename '<b>%1</b>':").arg(shrinkdn(fullname)+"</qt>"),
 				name,
 				&ok, mw)
 			.stripWhiteSpace());
-	if(ok && newName!="" && newName!=name)
+	#else
+	const QString newName(KInputDialog::getText(i18n("Rename %1").arg(name),
+					i18n("Enter new name:"),
+					 name,
+					 &ok, mw->iv).stripWhiteSpace());
+	#endif
+	if(ok && !newName.isEmpty() && newName!=name)
 	{
 		QString newDirName=dir->path()+"/"+newName;
 		if(QFileInfo(newDirName).exists())
@@ -1032,7 +797,7 @@ DirectoryView::renameDone( KIO::Job *job)
 	if(job->error()==0)
 	{
 		//pas d'erreurs
-		((Directory*)clickedItem)->rename();
+		clickedItem->rename();
 	}
 	else
 	{
@@ -1055,10 +820,17 @@ DirectoryView::slotNewAlbum (QListViewItem *item)
 {
   if(!item) return;
 	bool ok;
-	const QString newName(KLineEditDlg::getText("<qt>"+i18n("Create new album in <b>%1</b>").arg(shrinkdn(((Directory*)item)->fullName())+"</qt>"),
+	#if  KDE_VERSION < 0x30200
+	const QString newName(KLineEditDlg::getText("<qt>"+i18n("Create New Album in %1").arg(shrinkdn(((Directory*)item)->fullName())+"</qt>"),
 				i18n("Album"),
 				&ok, mw).stripWhiteSpace());
-	if(!ok || newName=="")
+	#else
+	const QString newName(KInputDialog::getText(i18n("Create New Album in %1").arg(shrinkdn(((Directory*)item)->fullName())),
+					i18n("Enter album name:"),
+					 i18n("Album"),
+					 &ok, mw->iv).stripWhiteSpace());
+	#endif
+	if(!ok || newName.isEmpty())
 		return;
 
 	KURL url("file:"+((Directory*)item)->fullName()+"/"+newName+".sia");
@@ -1086,10 +858,17 @@ DirectoryView::slotNewDir (QListViewItem *item)
 {
   if(!item) return;
 	bool ok;
-	const QString newName(KLineEditDlg::getText("<qt>"+i18n("Create new directory in <b>%1</b>").arg(shrinkdn(((Directory*)item)->fullName()))+"</qt>",
+	#if  KDE_VERSION < 0x30200
+	const QString newName(KLineEditDlg::getText("<qt>"+i18n("Create new directory in %1").arg(shrinkdn(((Directory*)item)->fullName()))+"</qt>",
 				i18n("Directory"),
 				&ok, mw).stripWhiteSpace());
-	if(!ok || newName=="")
+	#else
+	const QString newName(KInputDialog::getText(i18n("Create New Directory in %1").arg(shrinkdn(((Directory*)item)->fullName())),
+					i18n("Enter directory name:"),
+					 i18n("Directory"),
+					 &ok, mw->iv).stripWhiteSpace());
+	#endif
+	if(!ok || newName.isEmpty())
 		return;
 
 	KURL url("file:"+((Directory*)item)->fullName()+"/"+newName);
@@ -1114,11 +893,12 @@ DirectoryView:: slotTrash()
 void
 DirectoryView::slotTrash (QListViewItem *item)
 {
+#ifndef Q_WS_WIN
 	if(!item) return;
-	Directory *dir=(Directory*)item;
-	//if(dir->isSelected()){ dir->setSelected(false); mw->goUp();}
+	ListItem *dir=(ListItem*)item;
 	dir->setOpen(false);
-	KonqOperations::del(mw, KonqOperations::TRASH, KURL("file:/"+dir->fullName()));
+	KonqOperations::del(mw, KonqOperations::TRASH, dir->getURL());
+#endif
 }
 
 
@@ -1132,11 +912,12 @@ DirectoryView:: slotSuppr()
 void
 DirectoryView::slotSuppr (QListViewItem *item)
 {
+#ifndef Q_WS_WIN
 	if(!item) return;
 	Directory *dir=(Directory*)item;
-	//if(dir->isSelected()){ dir->setSelected(false); mw->goUp();}
 	dir->setOpen(false);
-	KonqOperations::del(mw, KonqOperations::DEL, KURL("file:/"+dir->fullName()));
+	KonqOperations::del(mw, KonqOperations::DEL, dir->getURL());
+#endif
 }
 
 void
@@ -1162,9 +943,10 @@ DirectoryView::slotDirCopy()
 	if(!item)
 		return;
 
-		QString destDir=KFileDialog::getExistingDirectory(lastDestDir.isEmpty()?item->fullName():lastDestDir,
+	QString destDir =
+		KFileDialog::getExistingDirectory(lastDestDir.isEmpty()?item->fullName():lastDestDir,
 									mw,
-									i18n("Copy directory %1 to...").arg(shrinkdn(item->fullName())));
+									i18n("Copy Directory %1 To").arg(shrinkdn(item->fullName())));
 
 	if(!destDir.isEmpty())
 	{
@@ -1191,7 +973,7 @@ DirectoryView::slotDirMove()
 
 		QString destDir=KFileDialog::getExistingDirectory(lastDestDir.isEmpty()?item->fullName():lastDestDir,
 								mw,
-								i18n("Move directory %1 to...").arg(shrinkdn(item->fullName())));
+								i18n("Move Directory %1 To").arg(shrinkdn(item->fullName())));
 
 	if(!destDir.isEmpty())
 	{
@@ -1199,13 +981,15 @@ DirectoryView::slotDirMove()
 		QString dest=destDir+"/"+item->text(0);
 		if(QFileInfo(dest).exists())
 		{
-		 	 KMessageBox::error(mw->iv, "<qt>"+i18n("The directory '<b>%1</b>' already exists").arg(shrinkdn(dest))+"</qt>");
+		 	 KMessageBox::error(mw->iv, "<qt>"
+			 	+i18n("The directory '<b>%1</b>' already exists").arg(shrinkdn(dest))+"</qt>");
 		 	 return;
 		}
 
 		if(!QFileInfo(QFileInfo(dest).dirPath()).isWritable())
 		{
-		 	 KMessageBox::error(mw->iv, "<qt>"+i18n("The directory '<b>%1</b>' is not writable").arg(shrinkdn(dest))+"</qt>");
+		 	 KMessageBox::error(mw->iv, "<qt>"
+			 	+i18n("The directory '<b>%1</b>' is not writable").arg(shrinkdn(dest))+"</qt>");
 		 	 return;
 		}
 
@@ -1221,43 +1005,6 @@ DirectoryView::slotDirMove()
 	}
 }
 
-bool
-DirectoryView::checkTrash()
-{
-	return trash;
-}
-
-void
-DirectoryView::setCheckTrash(bool trash)
-{
-	this->trash=trash;
-}
-
-bool
-DirectoryView::checkDelete()
-{
-	return del;
-}
-
-void
-DirectoryView::setCheckDelete(bool del)
-{
-	this->del=del;
-}
-
-bool
-DirectoryView::checkShred()
-{
-	return shred;
-}
-
-void
-DirectoryView::setCheckShred(bool shred)
-{
-	this->shred=shred;
-}
-
-
 void
 DirectoryView::setShowHiddenDir(bool show)
 {
@@ -1327,7 +1074,7 @@ DirectoryView::filter ()
 }
 
 bool
-DirectoryView::isImage(QString info)
+DirectoryView::isImage(const QString& info)
 {
 	QFileInfo *finfo = new QFileInfo(info);
 	bool isImg=isImage(finfo);
@@ -1339,33 +1086,63 @@ bool
 DirectoryView::isImage(QFileInfo *info)
 {
 
-	QString ext = info->extension( FALSE ).lower();
-	return			(
-				(ext == "jpg") ||  (ext == "jpeg") ||
-					(ext == "gif") ||
-					(ext == "png") ||
-					(ext == "bmp") ||
-					(ext == "tif") || (ext == "tiff")  ||
-					(ext == "mng") ||
-					(ext == "xpm") ||
-					(ext == "xcf") ||
-					(ext == "ico") ||
-					(ext == "pbm") ||
-					(ext == "eps") ||
-					(ext == "krl") ||
-					(ext == "pnm") ||
-					(ext == "pgm") ||
-					(ext == "ppm") ||
-					(ext == "psd") ||
-					(ext == "xbm") ||
-					KImageIO::canRead(KImageIO::type(info->filePath ()))
-					);
-
+        KMimeType::Ptr mime = KMimeType::findByPath( info->absFilePath(), 0, true );
+#if KDE_VERSION < 0x30200
+	if( mime->name() == KMimeType::defaultMimeType())
+		mime = KMimeType::findByFileContent( info->absFilePath() );
+        if(
+            mime->name() == "image/jpeg"
+         || mime->name() == "image/gif"
+         || mime->name() == "image/png"
+         || mime->name() == "image/x-bmp"
+         || mime->name() == "image/tiff"
+         || mime->name() == "image/xpm"
+         || mime->name() == "image/x-xcf"
+         || mime->name() == "image/x-gimp"
+         || mime->name() == "image/x-xcf-gimp"
+         || mime->name() == "image/x-ico"
+         || mime->name() == "image/pbm"
+         || mime->name() == "image/x-eps"
+         || mime->name() == "image/krl"
+         || mime->name() == "image/ppm"
+         || mime->name() == "image/x-psd"
+         || mime->name() == "image/xbm"
+         || mime->name() == "image/pgm")
+            return true;
+	else
+		return KImageIO::canRead(KImageIO::type(info->filePath ()));
+#else
+	if( mime->is(KMimeType::defaultMimeType()) )
+		mime = KMimeType::findByFileContent( info->absFilePath() );
+        if(
+            mime->is("image/jpeg")
+         || mime->is("image/gif")
+         || mime->is("image/png")
+         || mime->is("image/bmp")
+         || mime->is("image/tiff")
+         || mime->is("image/xpm")
+         || mime->is("image/xcf")
+         || mime->is("image/x-xcf")
+         || mime->is("image/x-gimp")
+         || mime->is("image/x-xcf-gimp")
+         || mime->is("image/xcf")
+         || mime->is("image/ico")
+         || mime->is("image/pbm")
+         || mime->is("image/eps")
+         || mime->is("image/krl")
+         || mime->is("image/ppm")
+         || mime->is("image/x-psd")
+         || mime->is("image/xbm")
+         || mime->is("image/pgm"))
+            return true;
+	else
+		return KImageIO::canRead(KImageIO::type(info->filePath ()));
+#endif
 }
 
 
 QString
-DirectoryView::shrinkdn(QString str)
+DirectoryView::shrinkdn(const QString& str)
 {
 	const unsigned int len=20;
 	if(str.length()<=len)
@@ -1381,4 +1158,87 @@ DirectoryView::dragObject ()
 	return NULL;
 }
 
+void
+DirectoryView::slotNewCDArchive()
+{
+#ifndef SHOWIMG_NO_CDARCHIVE
+	CDArchiveCreatorDialog dial(mw->getcdromPath(), mw);
+	dial.exec();
+#endif
+}
+
+void
+DirectoryView::initSelectedListItem()
+{
+	ListItem *rootItems = firstChild ();
+	while(rootItems)
+	{
+		initSelectedListItem(rootItems);
+		rootItems = rootItems->nextSibling();
+	}
+	setSelectionMode (QListView::Single);
+	oldCurrent=currentItem();
+}
+void
+DirectoryView::initSelectedListItem(ListItem *item)
+{
+	ListItem *myChild = item->firstChild();
+	if(item->isSelected())
+		oldCurrents.append(item);
+	while( myChild )
+	{
+		initSelectedListItem( myChild );
+		myChild = myChild->nextSibling();
+        }
+}
+
+void
+DirectoryView::restoreSelectedListItem()
+{
+	setUpdatesEnabled(FALSE);
+
+	clearSelection ();
+	setSelectionMode (QListView::Extended);
+	ListItem *item;
+	for ( item = oldCurrents.first(); item; item = oldCurrents.next() )
+		setSelected (item, TRUE);
+	setCurrentItem (oldCurrent);
+	oldCurrents.clear();
+	oldCurrent=NULL;
+
+	setUpdatesEnabled(TRUE);
+}
+
+int
+DirectoryView::getIconSize()
+{
+	return KIcon::SizeSmall;
+	//return KIcon::SizeMedium;
+}
+
+void
+DirectoryView::goToNextDir()
+{
+	if(!currentItem()) return;
+	ListItem * item = currentItem()->itemBelow();
+	if(!item) return;
+	clearSelection ();
+	setCurrentItem(item);
+	item->setSelected(true);
+	ensureItemVisible(item);
+}
+
+void
+DirectoryView::goToPreviousDir()
+{
+	if(!currentItem()) return;
+	ListItem * item = currentItem()->itemAbove();
+	if(!item) return;
+	clearSelection ();
+	setCurrentItem(item);
+	item->setSelected(true);
+	ensureItemVisible(item);
+}
+
+
 #include "directoryview.moc"
