@@ -13,6 +13,19 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #ifndef __DIRECTORYVIEW_H__
@@ -22,14 +35,7 @@
 #include <config.h>
 #endif
 
-#ifdef HAVE_LIBDIGIKAM
-#include <digikam/albummanager.h>
-namespace Digikam
-{
-class AlbumManager;
-}
-#endif
-
+// KDE 
 #include <klistview.h>
 #include <kio/job.h>
 
@@ -43,6 +49,7 @@ class KActionCollection;
 class KAction;
 class KDirWatch;
 class KListView;
+class KPopupMenu;
 class KIO::Job;
 
 class QDragEnterEvent;
@@ -56,16 +63,19 @@ class QProgressDialog;
 class QPopupMenu;
 class QDir;
 class QFileInfo;
+class QPoint;
 
 
-class DirectoryView : 	public KListView
+class DirectoryView : public KListView
 {
  Q_OBJECT
 
 public:
-	DirectoryView (QWidget * parent, ImageViewer * iv, ImageListView * imageList, MainWindow * mw);
-
+	DirectoryView (QWidget * parent, ImageViewer * iv, 
+			ImageListView * imageList, MainWindow * mw);
 
+	virtual ~DirectoryView();
+	
 	/**
 		the drag'n'drop events
 	*/
@@ -73,6 +83,7 @@ public:
 	void contentsDropEvent (QDropEvent * event);
 	void contentsDragMoveEvent (QDragMoveEvent * e);
 	void contentsDragLeaveEvent (QDragLeaveEvent *);
+	void contentsMouseMoveEvent (QMouseEvent *e);
 	
 	/**
 		the mouse event
@@ -88,35 +99,17 @@ public:
 	/**
 		copy a list of local (ie file:/) urls into  the dest directory
 	*/
-	void copy(QStringList uris, QString dest);
+	void copy(const QStringList& uris, const QString& dest);
 	/**
 		move a list of local (ie file:/) urls into  the dest directory
 	*/
-	void move(QStringList uris, QString dest);
+	void move(const QStringList& uris, const QString& dest);
 
 	/**	
 		@return true if the user is drropping files
 	*/
 	bool isDropping();
 
-	/**
-		return true if it have to show the warning message when move to trash files
-	*/
-	bool checkTrash();
-	void setCheckTrash(bool trash);
-	
-	/**
-		return true if it have to show the warning message when delete files
-	*/
-	bool checkDelete();
-	void setCheckDelete(bool del);
-	
-	/**
-		return true if it have to show the warning message when shred files
-	*/
-	bool checkShred();
-	void setCheckShred(bool shred);
-
 	/**
 		return true if it have to show the hidden directories
 	*/
@@ -136,7 +129,8 @@ public:
 	bool showDir();
   
 	/**
-		return true if it have to load the first image of the selected directory
+		return true if it have to load the first image of the selected
+		directory
 	*/
 	void setLoadFirstImage(bool load);
 	bool loadFirstImage();
@@ -149,15 +143,26 @@ public:
 
 	int filter();
 	bool isImage(QFileInfo *info);
-	bool isImage(QString info);
+	bool isImage(const QString& info);
 	
 	QPixmap* imagePixmap(){return image_pixmap;};
 
-	void removeDir(QString dirfullname);
+	ListItem* getDir(const QString& dirfullname);
+	void removeDir(const QString& path);
+	
+	ListItem* itemAt ( const QPoint & viewPos ) const;
+	ListItem* currentItem () const;
+	ListItem* firstChild() const;
+
+	static const int COLUMN_NAME=0;
+	static const int COLUMN_TYPE=1;
+	static const int COLUMN_SIZE=2;
+	static const int COLUMN_SELECT=3;
+
+	int getIconSize();
 
 private:
-	ListItem* getDir(QString dirfullname);
-	QString getDestName(QString orgFile, QString destDir);
+	QString getDestName(const QString& orgFile, const QString& destDir);
 	
 	enum OperationMode{NONE, COPY, MOVE};
 	
@@ -165,9 +170,9 @@ private:
 	bool move (QString *dep, QString *dest);
 	void copyNext();
 	void moveNext();
-	
-	bool trash, del, shred;
-	bool __showHiddenDir__, __showHiddenFile__,  __showDir__, __showAllFile__, __loadfirstimage__;
+
+	bool __showHiddenDir__, __showHiddenFile__,  __showDir__,
+		__showAllFile__, __loadfirstimage__;
 	bool dropping;
 
 	bool autoSkip;
@@ -184,18 +189,18 @@ private:
 	
 	QString lastDestDir;
 
-
 	ImageViewer *iv;
 	ImageListView *imageList;
 	MainWindow *mw;
 
 	QTimer *autoopen_timer;
-	QListViewItem *dropItem;
-	QListViewItem *oldCurrent;
+	ListItem *dropItem;
+	QPtrList < ListItem > oldCurrents;
+	ListItem *oldCurrent;
 
 	QProgressDialog *copyProgress;
-	QPopupMenu *popup;
-	QListViewItem *clickedItem;
+	KPopupMenu *popup;
+	ListItem *clickedItem;
 	KDirWatch *dirWatch;
 	
 	QPixmap *image_pixmap;
@@ -217,6 +222,8 @@ public slots:
 	void slotNewDir ();
 	void slotNewAlbum (QListViewItem *item);
 	void slotNewAlbum ();
+	void slotNewCDArchive();
+	
 	void slotSuppr (QListViewItem *item);
 	void slotSuppr ();
 	void slotTrash (QListViewItem *item);
@@ -232,6 +239,9 @@ public slots:
 	void slotDirMove();
   
 	void slotSelectionChanged ();
+	
+	void goToNextDir();
+	void goToPreviousDir();
 
 protected slots:
 	void copyingDone( KIO::Job *);
@@ -242,15 +252,17 @@ protected slots:
 	void movingDirDone( KIO::Job *);
 
 protected:
-	QString shrinkdn(QString str);
+	QString shrinkdn(const QString& str);
 	void updateActions(ListItem *item);
 	QDragObject * dragObject ();
 	
+	void initSelectedListItem();
+	void initSelectedListItem(ListItem *item);
+	void restoreSelectedListItem();
+	
 	KActionCollection *actionCollection;
 	
-#ifdef HAVE_LIBDIGIKAM
-	Digikam::AlbumManager *mAlbumMan;
-#endif /* HAVE_LIBDIGIKAM */
+
 };
 
 #endif
