@@ -13,10 +13,24 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #include "displayCompare.h"
 
+// Qt 
 #include <qlayout.h> 
 #include <qfileinfo.h> 
 #include <qimage.h>
@@ -25,8 +39,10 @@
 #include <qgroupbox.h>
 #include <qwhatsthis.h>
 
+// KDE 
 #include <ksqueezedtextlabel.h>
 #include <kapplication.h>
+#include <kglobal.h>
 
 DisplayCompare::DisplayCompare(QWidget* parent, QDict < QPtrVector < QFile > >* cmp )
 :KDialog(parent,"DisplayCompare",true)
@@ -117,7 +133,7 @@ DisplayCompare::DisplayCompare(QWidget* parent, QDict < QPtrVector < QFile > >*
     GroupBox8Layout->addWidget( listName );
 
     listEq = new QListView( GroupBox8, "listEq" );
-    listEq->addColumn( i18n( "Identical to" ) );
+    listEq->addColumn( i18n( "Identical To" ) );
     GroupBox8Layout->addWidget( listEq );
     CompareLayout->addWidget( GroupBox8 );
 
@@ -156,7 +172,7 @@ DisplayCompare::DisplayCompare(QWidget* parent, QDict < QPtrVector < QFile > >*
 		++itres;
 		n_id++;
 	}
-	GroupBox8->setTitle(i18n("Found %1 image(s)").arg(n_id));
+	GroupBox8->setTitle(i18n("Found %n Image","Found %n Images",n_id));
 	connect(listName, SIGNAL(selectionChanged ( QListViewItem * )), this, SLOT(slotDisplayLeft(QListViewItem *)));
 	connect(listEq, SIGNAL(selectionChanged ( QListViewItem * )), this, SLOT(slotDisplayRight(QListViewItem *)));
 
@@ -228,7 +244,7 @@ DisplayCompare::slotDisplayLeft(QListViewItem * item)
 						.arg(im.width())
 						.arg(im.height())
 						.arg(QFileInfo(item->text(0)).size())
-						.arg(KLocale(NULL).formatDateTime(QFileInfo(item->text(0)).lastModified()))
+						.arg(KGlobal::locale()->formatDateTime(QFileInfo(item->text(0)).lastModified()))
 					);
 
 		im = im.smoothScale(preview1->width(), preview1->height());
@@ -277,7 +293,7 @@ DisplayCompare::slotDisplayRight(QListViewItem * item)
 						.arg(im.width())
 						.arg(im.height())
 						.arg(QFileInfo(item->text(0)).size())
-						.arg(KLocale(NULL).formatDateTime(QFileInfo(item->text(0)).lastModified()))
+						.arg(KGlobal::locale()->formatDateTime(QFileInfo(item->text(0)).lastModified()))
 					);
 
 
