@@ -13,12 +13,29 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #ifndef __DISPLAYCOMPARE_H__
 #define __DISPLAYCOMPARE_H__
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
+// Qt 
 #include <qptrvector.h>
 #include <qdict.h>
 #include <qfile.h>
@@ -28,6 +45,7 @@
 #include <qgroupbox.h>
 #include <qheader.h>
 
+// KDE 
 #include <kapplication.h>
 #include <klocale.h>
 #include <kdialog.h>
