@@ -13,9 +13,21 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
-
 #include "exif.h"
 
 
@@ -243,6 +255,7 @@ static TagTable_t TagTable[] = {
 void ErrExit(const char * msg)
 {
     fprintf(stderr,"Error : %s\n", msg);
+    
 }
 //--------------------------------------------------------------------------
 // Read image data.
@@ -442,6 +455,7 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
         if (marker == 0xff){
             // 0xff is legal padding, but if we get that many, something's wrong.
             ErrExit("too many padding bytes!");
+	    return 0;
         }
 
         Sections[SectionsRead].Type = marker;
@@ -454,6 +468,7 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
 
         if (itemlen < 2){
             ErrExit("invalid marker");
+	    return 0;
         }
 
         Sections[SectionsRead].Size = itemlen;
@@ -461,6 +476,7 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
         Data = (uchar *)malloc(itemlen+1); // Add 1 to allow sticking a 0 at the end.
         if (Data == NULL){
             ErrExit("Could not allocate memory");
+	    return 0;
         }
         Sections[SectionsRead].Data = Data;
 
@@ -471,6 +487,7 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
         got = fread(Data+2, 1, itemlen-2, infile); // Read the whole section.
         if (got != itemlen-2){
             ErrExit("reading from file");
+	    return 0;
         }
         SectionsRead += 1;
 
@@ -490,11 +507,13 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
                     Data = (uchar *)malloc(size);
                     if (Data == NULL){
                         ErrExit("could not allocate data for entire image");
+			return 0;
                     }
 
                     got = fread(Data, 1, size, infile);
                     if (got != size){
                         ErrExit("could not read the rest of the image");
+			return 0;
                     }
 
                     Sections[SectionsRead].Data = Data;
@@ -625,14 +644,16 @@ static void WriteJpegFile(const char * FileName)
 {
     FILE * outfile;
     int a;
-
+    fprintf(stderr,"writing %s\n", FileName);
     if (!HaveAll){
         ErrExit("Can't write back - didn't read all");
+	return;
     }
 
     outfile = fopen(FileName,"wb");
     if (outfile == NULL){
         ErrExit("Could not open file for write");
+	return;
     }
 
     // Initial static jpeg marker.
@@ -805,6 +826,7 @@ static void ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBase,
         if ((Format-1) >= NUM_FORMATS) {
             // (-1) catches illegal zero case as unsigned underflows to positive large.
             ErrExit("Illegal format code in EXIF dir");
+	    return;
         }
 
         ByteCount = Components * BytesPerFormat[Format];
@@ -818,6 +840,7 @@ static void ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBase,
                 printf("Offset %d bytes %d ExifLen %d\n",OffsetVal, ByteCount, ExifLength);
 
                 ErrExit("Illegal pointer offset value in EXIF");
+		return;
             }
             ValuePtr = OffsetBase+OffsetVal;
         }else{
@@ -1029,6 +1052,7 @@ static void ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBase,
             SubdirStart = OffsetBase + Get32u(ValuePtr);
             if (SubdirStart < OffsetBase || SubdirStart > OffsetBase+ExifLength){
                 ErrExit("Illegal subdirectory link");
+		return;
             }
             ProcessExifDir(SubdirStart, OffsetBase, ExifLength);
             continue;
@@ -1047,6 +1071,7 @@ static void ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBase,
             SubdirStart = OffsetBase + Offset;
             if (SubdirStart < OffsetBase || SubdirStart > OffsetBase+ExifLength){
                 ErrExit("Illegal subdirectory link");
+		return;
             }
             ProcessExifDir(SubdirStart, OffsetBase, ExifLength);
         }
@@ -1159,6 +1184,7 @@ void process_EXIF(unsigned char * CharBuf, unsigned int length)
         static const uchar ExifHeader[] = "Exif\0\0";
         if (memcmp(CharBuf+2, ExifHeader,6)){
             ErrExit("Incorrect Exif header");
+	    return;
         }
     }
 
@@ -1171,6 +1197,7 @@ void process_EXIF(unsigned char * CharBuf, unsigned int length)
             MotorolaOrder = 1;
         }else{
             ErrExit("Invalid Exif alignment marker.");
+	    return;
         }
     }
 
@@ -1178,6 +1205,7 @@ void process_EXIF(unsigned char * CharBuf, unsigned int length)
     if (Get16u(CharBuf+10) != 0x2a
       || Get32u(CharBuf+12) != 0x08){
         ErrExit("Invalid Exif start (1)");
+	return;
     }
 
     LastExifRefd = CharBuf;
@@ -1498,6 +1526,7 @@ QString ProcessFile(const char * FileName, bool showsize, const char *ThumbnailN
             ImageInfo.FileSize = st.st_size;
         }else{
             ErrExit("No such file");
+	    return 0;
         }
     }
 
@@ -1563,16 +1592,18 @@ QString ProcessFile(const char * FileName, bool showsize, const char *ThumbnailN
 	    {
                 fwrite(ImageInfo.ThumbnailPointer, ImageInfo.ThumbnailSize ,1, ThumbnailFile);
                 fclose(ThumbnailFile);
-                //printf("Created: '%s'\n", OutFileName);
+                //fprintf(stderr, "EXIF: Created: '%s'\n", OutFileName);
 		ret="OK";
             }
 	    else
 	    {
-                ErrExit("Could not write thumbnail file");
+                ErrExit("Could not write thumbnail file: ");
+                ErrExit(OutFileName);
+		return 0;
             }
         }else
 	{
-            //printf("Image '%s' contains no thumbnail\n",FileName);
+            //fprintf(stderr, "EXIF: Image '%s' contains no thumbnail\n",FileName);
 	    ret="ERROR";
         }
     }
