@@ -13,13 +13,28 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
-
 #ifndef __EXIF_H__
 #define __EXIF_H__
 
-#define _MAX_PATH 300
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #define MAX_COMMENT 1000
 #ifndef TRUE
     #define TRUE 1
@@ -41,6 +56,10 @@
 
 #include <qstring.h>
 
+#ifndef _MAX_PATH
+# define _MAX_PATH 300
+#endif
+
 //--------------------------------------------------------------------------
 // This structure stores Exif header image elements in a simple manner
 // Used to store camera data as extracted from the various ways that it can be
