@@ -13,10 +13,26 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
+#define MYDEBUG kdDebug()<<__FILE__<<" " <<__LINE__ << " " << __FUNCTION__ << " "
+
 #include "extract.h"
 
+// KDE 
 #include <kprocess.h>
 #include <kio/job.h>
 #include <kzip.h>
@@ -25,12 +41,17 @@
 #include <kurl.h>
 #include <kmessagebox.h>
 #include <klocale.h>
+#include <kdebug.h>
+#include <kmimetype.h>
+#include <kapplication.h>
+#include <kstandarddirs.h>
 
+// Qt 
 #include <qdir.h>
 #include <qvaluelist.h>
 
 void 
-Extract::getEntryRecursive( const KArchiveDirectory * entry, const QString & path )
+Extract::getEntryRecursive( const KArchiveDirectory * entry, const QString& path )
 {
 	QStringList const & entries(entry->entries());
 	QStringList::const_iterator it = entries.begin();
@@ -46,23 +67,20 @@ Extract::getEntryRecursive( const KArchiveDirectory * entry, const QString & pat
 	}
 }
 
-Extract::Extract (QString _filename)
+Extract::Extract (const QString& _filename)
 {
 	QFileInfo fileinfo ( _filename );
 
-	QString  tmpdir;
-	tmpdir.setNum (getpid ());
-	tmpdir.prepend ("/tmp/.qlist");
-	QDir().mkdir(tmpdir,TRUE);
+	QString  tmpdir = locateLocal("tmp", "showimg-cpr/");
 
 	dest = tmpdir + '/' + fileinfo.fileName() + '/';
-	ext = fileinfo.extension().lower();
+	ext = fileinfo.extension(false).lower();
 
 	// Warn when the size of archive more than 'big(64MB).'
 	QFile::Offset big = 0x4000000;// 64MB
 	QFile qfile( _filename );
 	if( qfile.size() > big ) {
-		QString msg = QString( i18n("The size of selected archive seems to be TOO BIG!\nContinue?(size: %1MB)") ).arg( (qfile.size())>>20 );
+		QString msg = QString( i18n("The size of selected archive seems to be too big;\ncontinue? (size: %1MB)") ).arg( (qfile.size())>>20 );
 		switch( KMessageBox::warningContinueCancel( 0, msg, i18n("Confirm")) ) {
 			case KMessageBox::Cancel :
 				return;
@@ -70,13 +88,17 @@ Extract::Extract (QString _filename)
 		}
 	}
 
-	// KZip - sync
+        KMimeType::Ptr mime = KMimeType::findByPath( _filename );
+        // KArchive - sync
 	KArchive * arc=NULL;
-	if ( ext == "zip" )
+        if ( mime->name() == "application/x-zip" )
 		arc = new KZip( fileinfo.absFilePath() );
-	else if ( ext == "tar" || ext == "tar.gz" || ext == "tar.bz2" || ext == "tgz" )
+        else if ( mime->name() == "application/x-tar"
+               || mime->name() == "application/x-tarz"
+               || mime->name() == "application/x-tgz"
+               || mime->name() == "application/x-tbz" )
 		arc = new KTar( fileinfo.absFilePath() );
-	else if ( ext == "ar" )
+        else if ( mime->name() == "application/x-archive" )
 		arc = new KAr( fileinfo.absFilePath() );
 
 	if(arc)
@@ -91,42 +113,38 @@ Extract::Extract (QString _filename)
 	else
 		KMessageBox::error( 0, 
 			"<qt>"+i18n("Unable to open the archive '<b>%1</b>'.").arg(fileinfo.absFilePath())+"</qt>", 
-			i18n("Archive problem"));
+			i18n("Archive Error"));
 }
 
-void
-Extract::slotEntryRcv (KIO::Job *, const KIO::UDSEntryList& entries)
-{
-	KIO::UDSEntryListConstIterator it;
-	for(it = entries.begin(); it != entries.end(); ++it ){
-		KIO::UDSEntry::const_iterator jt;
-		for(jt = (*it).begin(); jt != (*it).end(); ++jt ){
-			switch( (*jt).m_uds ) {
-				case KIO::UDS_NAME:
-					files.append( QString((*jt).m_str) );
-					break;
-				default:
-					break;
-			}
-		}
-	}
-	emit finished(this);
-}
 
 bool
-Extract::canExtract( const QString & _filename )
+Extract::canExtract( const QString& _filename )
 {
 	QFileInfo info( _filename );
-	QString ext[2];
-	//allow for periods in filenames that aren't part of the extension
-	ext[0] = info.extension(true).lower();			
-	ext[1] = info.extension(false).lower();
-	for(int i = 0; i < 2; i++)	
-		if( ext[i] == "zip" || ext[i] == "tar" || ext[i] == "tar.gz" 
-		 || ext[i] == "tar.bz2" || ext[i] == "tgz" || ext[i] == "ar" )
-			return true;
-		
+        //Use KMime to check filetypes out.
+        KMimeType::Ptr mime;
+        mime = KMimeType::findByPath( _filename, 0, true );
+#if  KDE_VERSION < 0x30200
+	if( mime->name() == KMimeType::defaultMimeType())
+		mime = KMimeType::findByFileContent( _filename );
+        if( mime->name() == "application/x-zip"
+         || mime->name() == "application/x-tar"
+         || mime->name() == "application/x-tarz"
+         || mime->name() == "application/x-tgz"
+         || mime->name() == "application/x-tbz"
+         || mime->name() == "application/x-archive" )
+            return true;
+#else
+	if( mime->is(KMimeType::defaultMimeType()))
+		mime = KMimeType::findByFileContent( _filename );
+        if( mime->is("application/x-zip")
+         || mime->is("application/x-tar")
+         || mime->is("application/x-tarz")
+         || mime->is("application/x-tgz")
+         || mime->is("application/x-tbz")
+         || mime->is("application/x-archive") )
+            return true;
+#endif
 	return false;
 }
 
-#include "extract.moc"
