@@ -13,12 +13,27 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #include "formatconversion.h"
 
+// Local
 #include "jpgoptions.h"
 
+// Qt
 #include <qcheckbox.h>
 #include <qcombobox.h>
 #include <qgroupbox.h>
@@ -35,31 +50,23 @@
 
 
 
-/*
- *  Constructs a FormatConversion which is a child of 'parent', with the
- *  name 'name' and widget flags set to 'f'
- *
- *  The dialog will by default be modeless, unless you set 'modal' to
- *  TRUE to construct a modal dialog.
- */
-FormatConversion::FormatConversion( QWidget* parent,  const char* name, bool modal, WFlags fl )
-    : KDialog( parent, name, modal, fl )
-{
-	if ( !name )
-	    setName( "FormatConversion" );
-	setCaption( i18n( "Format Conversion" ) );
-	QWhatsThis::add(  this, i18n( "Frame to choose the format conversion" ) );
-    FormatConversionLayout = new QVBoxLayout( this, 11, 6, "FormatConversionLayout");
+FormatConversion::FormatConversion( QWidget* parent,  const char* name )
+:KDialogBase( parent, name, true, "FormatConversion" ,
+ 		    KDialogBase::Help|KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
 
-    GroupBox1 = new QGroupBox( this, "GroupBox1" );
+{
+    QWidget *page = new QWidget( this );
+    setMainWidget(page);
+//////////////////////////////
+    FormatConversionLayout = new QGridLayout( page, 1, 1, 11, 6, "FormatConversionLayout"); 
+
+    GroupBox1 = new QGroupBox( page, "GroupBox1" );
     GroupBox1->setColumnLayout(0, Qt::Vertical );
     GroupBox1->layout()->setSpacing( 6 );
     GroupBox1->layout()->setMargin( 11 );
-    GroupBox1Layout = new QVBoxLayout( GroupBox1->layout() );
+    GroupBox1Layout = new QGridLayout( GroupBox1->layout() );
     GroupBox1Layout->setAlignment( Qt::AlignTop );
 
-    layout8 = new QHBoxLayout( 0, 0, 6, "layout8"); 
-
     listViewFormat = new QListView( GroupBox1, "listViewFormat" );
     listViewFormat->addColumn( i18n( "Extension" ) );
     listViewFormat->header()->setClickEnabled( FALSE, listViewFormat->header()->count() - 1 );
@@ -68,52 +75,39 @@ FormatConversion::FormatConversion( QWidget* parent,  const char* name, bool mod
     listViewFormat->header()->setClickEnabled( FALSE, listViewFormat->header()->count() - 1 );
     listViewFormat->header()->setResizeEnabled( FALSE, listViewFormat->header()->count() - 1 );
     listViewFormat->setAllColumnsShowFocus( TRUE );
-    layout8->addWidget( listViewFormat );
 
-    layout2 = new QVBoxLayout( 0, 0, 6, "layout2"); 
-    QSpacerItem* spacer = new QSpacerItem( 20, 41, QSizePolicy::Minimum, QSizePolicy::Expanding );
-    layout2->addItem( spacer );
+    GroupBox1Layout->addMultiCellWidget( listViewFormat, 0, 0, 0, 1 );
+    spacer4 = new QSpacerItem( 180, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+    GroupBox1Layout->addItem( spacer4, 1, 0 );
 
     pushButtonSetting = new QPushButton( GroupBox1, "pushButtonSetting" );
     pushButtonSetting->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, 0, 0, pushButtonSetting->sizePolicy().hasHeightForWidth() ) );
-    layout2->addWidget( pushButtonSetting );
-    layout8->addLayout( layout2 );
-    GroupBox1Layout->addLayout( layout8 );
 
-    layout6 = new QHBoxLayout( 0, 0, 6, "layout6"); 
+    GroupBox1Layout->addWidget( pushButtonSetting, 1, 1 );
 
     CheckBox1 = new QCheckBox( GroupBox1, "CheckBox1" );
-    layout6->addWidget( CheckBox1 );
-    QSpacerItem* spacer_2 = new QSpacerItem( 111, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
-    layout6->addItem( spacer_2 );
-    GroupBox1Layout->addLayout( layout6 );
-    FormatConversionLayout->addWidget( GroupBox1 );
 
-    layout3 = new QHBoxLayout( 0, 0, 6, "layout3"); 
-    QSpacerItem* spacer_3 = new QSpacerItem( 41, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
-    layout3->addItem( spacer_3 );
+    GroupBox1Layout->addMultiCellWidget( CheckBox1, 3, 3, 0, 1 );
 
-    pushButtonOK = new QPushButton( this, "pushButtonOK" );
-    layout3->addWidget( pushButtonOK );
+    line1 = new QFrame( GroupBox1, "line1" );
+    line1->setFrameShape( QFrame::HLine );
+    line1->setFrameShadow( QFrame::Sunken );
+    line1->setFrameShape( QFrame::HLine );
 
-    pushButtonCancel = new QPushButton( this, "pushButtonCancel" );
-    layout3->addWidget( pushButtonCancel );
-    FormatConversionLayout->addLayout( layout3 );
+    GroupBox1Layout->addMultiCellWidget( line1, 2, 2, 0, 1 );
 
-    resize( QSize(433, 326).expandedTo(minimumSizeHint()) );
+    FormatConversionLayout->addWidget( GroupBox1, 0, 0 );
+    //languageChange();
+    resize( QSize(371, 295).expandedTo(minimumSizeHint()) );
     clearWState( WState_Polished );
 
     // signals and slots connections
-    connect( pushButtonOK, SIGNAL( clicked() ), this, SLOT( accept() ) );
-    connect( pushButtonCancel, SIGNAL( released() ), this, SLOT( reject() ) );
     connect( listViewFormat, SIGNAL( selectionChanged(QListViewItem*) ), this, SLOT( enabledDisabledSettingButton(QListViewItem*) ) );
 
     // tab order
     setTabOrder( listViewFormat, pushButtonSetting );
-    setTabOrder( pushButtonSetting, pushButtonOK );
-    setTabOrder( pushButtonOK, pushButtonCancel );
 
-    //////////////////////////////
+//////////////////////////////
 
 	QListViewItem * item = new QListViewItem( listViewFormat, 0 );
 	item->setText( 0,  "BMP"  );
@@ -121,7 +115,7 @@ FormatConversion::FormatConversion( QWidget* parent,  const char* name, bool mod
 
 	item = new QListViewItem( listViewFormat, item );
 	item->setText( 0,  "GIF"  );
-	item->setText( 1, ( " CompuServe Graphics Interchange format" ) );
+	item->setText( 1, ( "CompuServe Graphics Interchange format" ) );
 
 	item = new QListViewItem( listViewFormat, item );
 	item->setText( 0,  "JPG"  );
@@ -178,18 +172,19 @@ FormatConversion::FormatConversion( QWidget* parent,  const char* name, bool mod
 
 
     QWhatsThis::add( listViewFormat, i18n( "Choose your format here" ) );
-    pushButtonSetting->setText( i18n( "Format &Setting ..." ) );
+    GroupBox1->setTitle( i18n( "Destination Format" ) );
+    pushButtonSetting->setText( i18n( "Format &Setting..." ) );
     QWhatsThis::add( pushButtonSetting, i18n( "Edit the setting of\n"
 "the selected format" ) );
     CheckBox1->setText( i18n( "Remove/replace original" ) );
-    QWhatsThis::add( CheckBox1, i18n( "Have to replace the original ?" ) );
-    pushButtonOK->setText( i18n( "&OK" ) );
-    pushButtonCancel->setText( i18n( "&Cancel" ) );
+    QWhatsThis::add( CheckBox1, i18n( "Have to replace the original?" ) );
 
 	////
 	options=QString(" ");
 	connect( listViewFormat, SIGNAL( selectionChanged(QListViewItem*) ), this, SLOT( enabledDisabledSettingButton(QListViewItem*) ) );
 	connect( pushButtonSetting, SIGNAL( clicked() ), this, SLOT( showJPGOption() ) );
+
+	opt=NULL;
 }
 
 /*
@@ -225,11 +220,10 @@ void FormatConversion::enabledDisabledSettingButton(QListViewItem* item)
 }
 void FormatConversion::showJPGOption()
 {
-	JPGOptions opt (this);
-	int res = opt.exec();
-	switch(res)
+	if(!opt) opt = new JPGOptions(this);
+	switch(opt->exec())
 	{
-		case QDialog::Accepted : options = opt.getOptions();
+		case KDialogBase::Accepted : options = opt->getOptions();
 		default:;
 	}
 }
