@@ -14,22 +14,39 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #include "imagefileinfo.h"
 
+// QT
 #include <qfileinfo.h> 
 #include <qtextstream.h> 
-#include <qglobal.h> 
+#include <qglobal.h>
 #include <qdir.h> 
 
+// KDE 
 #include <kio/job.h>
 #include <klocale.h>
+#include <kdebug.h>
+#include <kstandarddirs.h>
 
 #include <sys/types.h>
 #include <unistd.h>
 
-ImageFileInfo::ImageFileInfo(QString filename, int type, bool r)
+ImageFileInfo::ImageFileInfo(const QString& filename, int type, bool r)
 {
 	this->type=type;
 	this->filename=QFileInfo(filename).dir(true).absPath()+"/descriptions.txt";
@@ -43,7 +60,7 @@ ImageFileInfo::~ImageFileInfo()
 }
 
 void
-ImageFileInfo::update(QString )
+ImageFileInfo::update(const QString& )
 {
 }
 
@@ -133,11 +150,11 @@ ImageFileInfo::write(QString title, QString event,
 		tag="<name>"+imageid+"</name>";
 	bool trouve=false;
 	
-	QFile ftemp("/tmp/showimg_temp"+QString().setNum(getpid()));
+	QFile ftemp(locateLocal("tmp", "showimg-net/showimg_temp"+QString().setNum(getpid())));
 	if (!ftemp.open(IO_WriteOnly) )
 		return;
 	QTextStream tstemp(&ftemp);
-	
+
 	while(isOpen && !ts.eof() && !trouve)
 	{
 		lut=ts.readLine ();
@@ -169,21 +186,38 @@ ImageFileInfo::write(QString title, QString event,
 	
 	while(isOpen && !ts.eof())
 	{
-		lut=ts.readLine ();		
+		lut=ts.readLine ();
 		tstemp << lut <<"\n";
-		
+
 	}
 	ftemp.close();
-	f.close();	
-	
+	f.close();
+
+	//
+	f.open(IO_WriteOnly);
+	QTextStream ts1(&f);
+	ftemp.open(IO_ReadOnly);
+	QTextStream tstemp1(&ftemp);
+	while(isOpen && !tstemp1.eof())
+	{
+		lut=tstemp1.readLine ();
+		ts1 << lut <<"\n";
+
+	}
+	ftemp.close();
+	f.close();
+
+
+	/*
 	KIO::file_move(KURL("file:/"+ftemp.name() ), KURL("file:/"+fileDest), -1,
 				  true, false,
 				  false);
+	*/
 
 }
 
 void
-ImageFileInfo::write(QString title, 
+ImageFileInfo::write(QString title,
 		QString shortdesc, QString longdesc,
 		QString fileDest)
 {
@@ -260,7 +294,7 @@ ImageFileInfo::write(QString title,
 
 
 bool 
-ImageFileInfo::verif(QString info)
+ImageFileInfo::verif(const QString& info)
 {
 	if(info.contains("<name>") || info.contains("</name>") ||
 	info.contains("<properties>") || info.contains("</properties>") ||
@@ -290,7 +324,7 @@ ImageFileInfo::getTitle() const
 }
 
 void 
-ImageFileInfo::setTitle(QString title)
+ImageFileInfo::setTitle(const QString& title)
 {
 	this->title=title;
 }
@@ -307,7 +341,7 @@ ImageFileInfo::getEvent() const
 }
 
 void 
-ImageFileInfo::setEvent(QString event)
+ImageFileInfo::setEvent(const QString& event)
 {
 	this->event=event;
 }
@@ -325,7 +359,7 @@ ImageFileInfo::getLocation() const
 }
 
 void 
-ImageFileInfo::setLocation(QString location)
+ImageFileInfo::setLocation(const QString& location)
 {
 	this->location=location;
 }
@@ -342,7 +376,7 @@ ImageFileInfo::getPeople() const
 }
 
 void 
-ImageFileInfo::setPeople(QString people)
+ImageFileInfo::setPeople(const QString& people)
 {
 	this->people=people;
 }
@@ -359,7 +393,7 @@ ImageFileInfo::getDate() const
 }
 
 void 
-ImageFileInfo::setDate(QString date)
+ImageFileInfo::setDate(const QString& date)
 {
 	this->date=date;
 }
@@ -376,7 +410,7 @@ ImageFileInfo::getDescription() const
 }
 
 void 
-ImageFileInfo::setDescription(QString description)
+ImageFileInfo::setDescription(const QString& description)
 {
 	this->description=description;
 }
@@ -395,7 +429,7 @@ ImageFileInfo::getShortDescription() const
 }
 
 void  
-ImageFileInfo::setShortDescription(QString shortdesc )
+ImageFileInfo::setShortDescription(const QString& shortdesc )
 {
 	this->shortdesc=shortdesc;
 }
@@ -414,7 +448,7 @@ ImageFileInfo::getLongDescription() const
 	
 }
 void  
-ImageFileInfo::setLongDescription(QString longdesc)
+ImageFileInfo::setLongDescription(const QString& longdesc)
 {
 	this->longdesc=longdesc;
 }
