@@ -14,28 +14,50 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #include "kexifpropsplugin.h"
+
+// Local 
 #include "exif.h"
 
+// Qt 
 #include <qheader.h>
 #include <qlayout.h>
 #include <qclipboard.h> 
 #include <qdragobject.h>
 #include <qpushbutton.h>
 #include <qcolor.h>
+#include <qfile.h>
 
+// KDE 
 #include <klocale.h>
 #include <klistview.h>
 #include <kapplication.h> 
 
-KEXIFPropsPlugin::KEXIFPropsPlugin( KPropertiesDialog *_props, QString fileName )
+KEXIFPropsPlugin::KEXIFPropsPlugin( KPropertiesDialog *_props, const QString& fileName )
 :KPropsDlgPlugin(_props)
 {
+	#if  KDE_VERSION < 0x30200
 	KDialogBase *dialog=_props->dialog();
+	#else
+	KPropertiesDialog *dialog=_props;
+	#endif	
 	QFrame *page=dialog->addPage( i18n("&Metadata"));
-	QString info=ProcessFile(fileName.ascii ());
+	QString info=ProcessFile(QFile::encodeName(fileName));
 	this->info=info;
 
 	QBoxLayout *lyMain=new QVBoxLayout(page);
