@@ -13,6 +13,19 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #ifndef MAINWINDOW_H
@@ -22,11 +35,15 @@
 #include <config.h>
 #endif
 
+// Local 
+#include "showimg_export.h"
 #include "history_action.h"
 
+// KDE 
 #include <kdockwindow.h>
 #include <kbookmarkmanager.h>
 #include <kdockwidget.h>
+#include <kio/job.h>
 
 class Directory;
 class DirectoryView;
@@ -37,14 +54,12 @@ class HistoryAction;
 class ListItem;
 class ImageSimilarityData;
 class RenameSeries;
-
-#ifdef HAVE_LIBDIGIKAM
-class DigikamPluginManager;
-namespace Digikam
-{
-class AlbumManager;
-}
-#endif
+class ImageMetaInfo;
+class CDArchive;
+class FormatConversion;
+#ifdef HAVE_KIPI
+class KIPIPluginManager;
+#endif /*HAVE_KIPI*/
 
 class QKeyEvent;
 class QFile;
@@ -56,7 +71,6 @@ class QString;
 class QCloseEvent;
 class QImage;
 class QListViewItem;
-class QProgressDialog;
 class QProgressBar;
 
 class KDockMainWindow;
@@ -74,15 +88,15 @@ class KProgress;
 class KActionCollection;
 class KURLCompletion;
 class KHistoryCombo;
+class KProgressDialog;
+class KSqueezedTextLabel;
 
-
-
-class MainWindow:public KDockMainWindow, public KBookmarkOwner
+class SHOWIMGCORE_EXPORT MainWindow:public KDockMainWindow, public KBookmarkOwner
 {
 	Q_OBJECT
 public:
-	MainWindow (QString name="MainWindow");
-	MainWindow (QString pic, QString);
+	MainWindow (const QString& name="MainWindow");
+	MainWindow (const QString& pic, const QString&);
 
 	~MainWindow();
 
@@ -103,17 +117,17 @@ public:
 
 	DirectoryView* getDirectoryView();
 	ListItem* findDir(QString);
-	void nextDir (Directory * r);
+	void nextDir (ListItem *r);
 
 	/**
 		open a directory given its fullname
 	*/
-	bool openDir (QString);
+	bool openDir (const QString& dir, bool updateHistory_=TRUE);
 
 	/**
 		diplay the txt in the status bar
 	*/
-	void setMessage (QString txt);
+	void setMessage (const QString& txt);
 	
 	/**
 		set the number of item in the file view in the statusbar
@@ -123,17 +137,17 @@ public:
 	/**
 		set the zoom of displayed image in the statusbar
 	*/	
-	void setZoom (int zoom);
+	void setZoom (float zoom);
 	
 	/**
 		set the Imagename of displayed image in the statusbar
 	*/	
-	void setImagename (QString name);
+	void setImagename (const QString& name);
 	
 	/**
 		set the Imagetype of displayed image in the statusbar
 	*/
-	void setImagetype (QString type);
+	void setImagetype (const QString& type);
 
 	/**
 		set the Imagetype of displayed image in the statusbar
@@ -143,7 +157,7 @@ public:
 	/**
 		set the Dimension of displayed image in the statusbar
 	*/	
-	void setDim (QSize *size);
+	void setDim (const QSize& size, float dpi=0);
 	
 	/**
 		set the Size  of displayed image in the statusbar
@@ -154,6 +168,7 @@ public:
 		set the Date  of displayed image in the statusbar
 	*/	
 	void setDate (QDateTime *date);
+	void setDate (const QString& date);
 	
 	/**
 	*/
@@ -168,7 +183,6 @@ public:
 		@return true if icons preview is enabled
 	*/
 	bool preview();	
-	void setOnTop(bool onTop);
 
 	//
 	/**
@@ -200,7 +214,7 @@ public:
 	/**
 	* add the url in the groupText group of the bookmark
 	*/
-	void addToBookmark(QString groupText, QString url);
+	void addToBookmark(const QString& groupText, const QString& url);
 
 	//
 	/**
@@ -211,16 +225,21 @@ public:
 	/**
 		copy uris to the specified directory
 	*/
-	void copyFilesTo(QStringList uris, QString dest);
+	void copyFilesTo(const QStringList& uris, const QString& dest);
 	
 	/**
 		move uris to the specified directory
 	*/
-	void moveFilesTo(QStringList uris, QString dest);
+	void moveFilesTo(const QStringList& uris, const QString& dest);
 
 	void startWatchDir();
 	void stopWatchDir();
 	
+	QString getcdromPath();
+	
+	void readConfig(KConfig *config);
+	void writeConfig(KConfig *config);
+	
 	KProgress *progress;
 	int total;
 	int done;
@@ -228,10 +247,16 @@ public:
 	ImageViewer *iv;
 	ImageListView *imageList;
 	DirectoryView *dirView;
+	ImageMetaInfo *imageMetaInfo;
+
+#ifdef HAVE_KIPI
+	 KIPIPluginManager* pluginManager();
+#endif /*HAVE_KIPI*/
 
 
 public slots:
 	void clearCache();
+	void clearCacheRec();
 	void updateCache();
 
 	void setHasImageSelected(bool selected);
@@ -239,49 +264,32 @@ public slots:
 	void slotFullScreen (); //switch to full screen and windows mode
 	void slotSlideShow ();  //launch the slide show
 	void slotPreview ();	  //show/hide thes thumbertails
-	void slotRefresh ();	 //refresh the image list
-	void slotRefresh (QString dir);	//refresh a specifique dir
-	void slotKeepFit();	   // fit/unfit to screen
-	void slotfitWidth();	   
-	void slotfitHeight();	   
-	void slotEnlarge ();
-	void slotShrink ();
-	void slotSmooth ();    //smooth/unsmooth
+	void slotRefresh (bool forceRefresh=false);	 //refresh the image list
+	void slotRefresh (const QString& dir);	//refresh a specifique dir
+	
 	void slotCompareFast (){compareFast();}; //compare the pictures loaded
 	void slotCompareAlmost (){compareAlmost();}; //compare the pictures loaded
 
-	void myDialogSlot();  
-	void convert();  
+	void convert();
 
 	void slotNewWindow();
-	void slotPrint();
-	void slotQuickPrint();
 	void slotUndo();
 	void slotRedo();
-	void slotMovetotrash();
-	void slotShred();    
 
 	void slotOpenLocation();
 	void slotSaveImage();
 
-
 	void slotTODO ();
 	void slotcopy ();
 	void slotcopyPixmap ();
 	void slotcut ();
 	void slotpaste ();
-	void slotRotateLeft();
-	void slotRotateRight();
 	void slotStop();
-	void slotZoomIn();
-	void slotZoomOut() ;
-	void slotZoom();
-	void slotZoomNo();
-	void slotZoomLock();
+
 	void configureKey();
 	void configureToolbars();
 	void configureShowImg();
-	void slotBookmark();
+	void slotShowTips();
 
 	void slotForward();
 	void slotBack();
@@ -290,22 +298,22 @@ public slots:
 
 	void slotAddImage (int number=1);
 	void slotRemoveImage();
-	void slotPreviewDone ();
+	void slotPreviewDone (int number=1);
 	void slotReset (bool init=true);
 	void slotDone ();
 	void slotRemoveImage (int val);
-	void slotMirrorH ();
-	void slotMirrorV ();
-	void slotDirChange (const QString & dir);
-	void slotFileChange (const QString &);
-	void slotPreferences();
+
+	void slotDirChange (const QString& path);
+	void slotDirChange_created(const QString& path);
+	void slotDirChange_deleted(const QString& path);
+	
 	void slotEditFileType();
 	void renameSeries();
 
 	void slotArrangement();
 	void slotTxtPos();
 	
-	void slotIconSize(bool refresh=false);
+	void slotIconSize(bool refresh=true);
 
 	void changeDirectory(QString);
 	void changeDirectory();
@@ -315,29 +323,30 @@ public slots:
 	void slotForwardAboutToShow();
 	void slotBackAboutToShow();
 
-	void quit();
+	//void quit();
+	bool queryClose();
 	bool closeAppl();
 
-	void slotDirCut();
-	void slotDirCopy();
-	void slotDirMove();
-	void slotDirPaste();
-
 	void toolsRotateLeft();
 	void toolsRotateRight();
-
-	void slotSetFilter();
 	
 	void slotScanImage();
 	void slotScanned( const QImage&, int );
 
 	void slotDisplayNBImg();
 
+	/**
+		set the zoom of displayed image 
+	*/	
+	void setZoom ( const QString&);
+
+
 private slots:
 	void slotEndConvert(KProcess *);
 	void escapePressed();
 	void spacePressed();
-	
+	void updateWindowActions();
+	void deleteTempDirectoriesDone( KIO::Job *job );
 	
 protected:
 	KActionCollection *m_actions;
@@ -345,14 +354,14 @@ protected:
 	void setupStatusBar();
 
 	bool inFullScreen;
-	QProgressDialog *pdCache;
+	KProgressDialog *pdCache;
 
 	void init ();
 
 	void closeEvent( QCloseEvent* );
 
-	void clearCache(QString fromDir);
-	void updateCache(QString fromDir);
+	void clearCacheRec(const QString& fromDir);
+	KURL::List updateCache(const QString &fromDir);
 
 	QString getFileName(QString *fullName);
 	QString getFileExt(QString *fullName);
@@ -363,7 +372,7 @@ protected:
 	inline char getGreen(QImage *im, int x, int y);
 	inline char getBlue(QImage *im, int x, int y);
 
-	ImageSimilarityData* image_sim_fill_data(QString filename);
+	ImageSimilarityData* image_sim_fill_data(const QString& filename);
 	float image_sim_compare(ImageSimilarityData *a, ImageSimilarityData *b);
 	float image_sim_compare_fast(ImageSimilarityData *a, ImageSimilarityData *b, float min);
 
@@ -371,7 +380,7 @@ protected:
 	void go( int steps );
 	
 	QString currentDir() const;
-	void setCurrentDir(QString dir);
+	void setCurrentDir(const QString& dir);
 
 	QLabel *label;
 
@@ -381,32 +390,42 @@ protected:
 	KDockWidget *dockIV;
 	KDockWidget *dockDir;
 	KDockWidget *dockIL;
+	KDockWidget *dockIMI;
 
 	Directory *root;
-
-
+	CDArchive *cdArchiveRoot;
+	
 	QSize oldSize;
 	QPoint oldPos;
 
 	QTimer *timer;
 
 	KToolBar *mainToolbar, *pathToolbar;
+#ifndef SHOWIMG_NO_SCAN_IMAGE
 	KScanDialog *m_scanDialog;
+#endif
 	RenameSeries *m_renameS;
 
 
 private:
+
+	KSqueezedTextLabel *SB_NAME_Label, *SB_DATE_Label;
+
 	KConfig *config;
 	
+	FormatConversion *formatConver;
+	
 	QColor bgColor;
 	bool checkDelete, checkShred, checkTrash;
 	int grayscale, slideshowTime, slideshowType, openDirType;
 	bool storeth, showFrame;
 	bool smooth;
 	QString openDirname;
-	bool showSP, useEXIF;
+	bool showSP, startFS;
 	bool showToolbar, showStatusbar;
 
+	QString cdromPath, convertPath, jpegtranPath;
+	
 	bool hasimageselected;
 	QString currentDir_;
 	QString lastDestDir;
@@ -419,21 +438,23 @@ private:
 	int nbrItems; //number of item
 	int imageIndex; //current item index
 
-	void createActions();  
+	void createActions(); 
+	void createHideShowAction(KDockWidget* dock) ;
 	void createAccels();
 	void createMenus();
 	void createToolbar();
 	void createStatusbar();
 	void createMainView();
-	void initSize();
 	void setLayout(int layout);
+	void deleteTempDirectories();
 
+	bool deleteTempDirectoriesDone_;
 	
 	KActionCollection *actionCollect;
 
 	KAction *aCut, *aCopy, *aPaste, *aDelete, *aCopyPixmap,
 	      *aNewWindow,
-	      *aPrint, *aQuickPrint,
+	      *aQuickPrint,
 	      *aOpenLocation, *aSaveImage,
 	      *aQuit,*aClose,
 	      *aUndo,*aRedo,
@@ -442,17 +463,19 @@ private:
 	      *aImageInfo, *aDirInfo,
 	      *aSelect,*aUnselect,*aUnselectAll,*aInvertSelection,
 	      *aPrevious,*aNext,*aFirst,*aLast,
+	      *aPreviousDir,*aNextDir,
 	      *aConfigureKey,*aConfigureToolbars,*aConfigureShowImg,
 	      *aRenameSeries,
 	      *aCompareFast,*aCompareAlmost,*aCovert,
-	      *aRotLeft,*aRotRight,*aHMirror,*aVMirror,
 	      *aReloadDir,*aStop,
-	      *aZoomIn,*aZoomOut,*aZoomNo,*aZoomFit,
 	      *aOpenWithGimp, *aOpenWithKhexedit, *aOpenWith,
 	      *aWallpaper_CENTER,*aWallpaper_MOSAIC,*aWallpaper_CENTER_MOSAIC,*aWallpaper_CENTER_MAX,*aWallpaper_ADAPT,*aWallpaper_LOGO,
 
 	      *aDirNewFolder, *aDirProperties,
 	      *aDirNewAlbum,
+#ifndef SHOWIMG_NO_CDARCHIVE
+	      *aDirNewCDArchive,
+#endif
 	      *aDirCut, *aDirCopy, *aDirPaste, *aDirMove, *aDirPasteFiles, *aDirRecOpen,
 	      *aDirRename, *aDirTrash, *aDirDelete,
 	      *aDirBookmark,
@@ -464,43 +487,42 @@ private:
 
 	      *aGoHome, *aGoUp, *aGo,
 
-	      *aClearCache, *aUpdateCache,
+	      *aClearCache, *aClearCacheRec, *aUpdateCache,
 	      
+#ifndef SHOWIMG_NO_SCAN_IMAGE
 	      *aScan,
-
-	      *aTime;
+#endif
+	      *aTime,
+	      
+	      *aDisplayExifInformation;
 
 	HistoryAction *aBack, *aForward;
 	HistoryEntryList m_lstHistory;
 	KHistoryCombo *m_URLHistory;
 	KURLCompletion *m_URLHistoryCompletion;
+	
+	KComboBox *m_zoomCombo;
 
 	KToggleAction *aSlideshow,
-	      *aSmooth,
 	      *aPreview,
-	      *aEnlarge, *aShrink,
-	      *aZoomLock, *aZoomFitWidth, *aZoomFitHeight,
-	      *aFullScreen,
-
-	      *aEffect_NORMALIZE,*aEffect_EQUALIZE,*aEffect_INTENSITY, *aEffect_INVERT, *aEffect_GRAYSCALE,
-	      *aEffect_EMBOSS,*aEffect_SWIRL,*aEffect_SPREAD,*aEffect_IMPLODE,*aEffect_CHARCOAL,
-	      *aEffect_NONE;
-
+	      *aFullScreen;
 
 	KRadioAction
 	      *aIconSmall, *aIconMed, *aIconBig,
 	      *aArrangementLR, *aArrangementTB,
 	      *aArrangementB, *aArrangementR,
-	      *aSortBySize,*aSortByType,*aSortByName, *aSortByDate;
+	      *aSortBySize,*aSortByDirName,*aSortByType,*aSortByName, *aSortByDate;
 
 	KAccel* mAccel;
 	KActionMenu* abookmarkmenu;
 
 	KBookmarkMenu *mBookMenu;
-#ifdef HAVE_LIBDIGIKAM
-	DigikamPluginManager *pluginManager_;
-	Digikam::AlbumManager *mAlbumManager;
-#endif
+
+	QPtrList<KAction> m_windowListActions;
+	
+#ifdef HAVE_KIPI
+	 KIPIPluginManager *pluginManager_;
+#endif /*HAVE_KIPI*/
 
 };
 
