@@ -13,16 +13,31 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #include "printImageDialog.h"
 
 #include <stdio.h>
 
+// Qt 
 #include <qpainter.h>
 #include <qframe.h>
 #include <qlayout.h>
 
+// KDE 
 #include <kapplication.h>
 #include <klocale.h>
 #include <kdialog.h>
@@ -32,10 +47,10 @@ extern int min(int a, int b);
 extern int max(int a, int b);
 
 
-printImageDialog::printImageDialog(QWidget *parent, QPixmap pixmap, QString name, KPrinter *p)
+printImageDialog::printImageDialog(QWidget *parent, const QPixmap& pixmap, const QString& name, KPrinter *p)
 	: KDialog(parent,"printdialog", true)
 {
-	setCaption(i18n("Print image..."));
+	setCaption(i18n("Print Image"));
 
 	prn=p;
 	imageName=name;
@@ -50,7 +65,7 @@ printImageDialog::printImageDialog(QWidget *parent, QPixmap pixmap, QString name
 	lyMain->addStrut(int(pageSize.width()*pageScale+10));	
 	lyMain->addSpacing(10);
 	
-	float maxScale = (int )min(100*pageSize.width()/pix.width(),
+	double maxScale = (int )min(100*pageSize.width()/pix.width(),
 				100*pageSize.height()/pix.height());
 
 	if ((scale*100) > (maxScale*0.9))
@@ -134,9 +149,10 @@ printImageDialog::printImage()
 	
 	KApplication::setOverrideCursor (waitCursor); // this might take time
 	
+#ifndef Q_WS_WIN
 	prn->setCreator("showimg");
 	prn->setDocName(imageName);
-	
+#endif
 	QPainter p;
 	p.begin(prn);
 	paintImage(&p);
@@ -172,6 +188,7 @@ QRect
 printImageDialog::pageDimensions()
 {
 	QSize dims;
+#ifndef Q_WS_WIN
 	switch (prn->pageSize()) {
 	case QPrinter::A4:
 		dims=QSize(210, 297);
@@ -192,7 +209,7 @@ printImageDialog::pageDimensions()
 		dims=QSize(210, 297);
 	}
 	// Convert to points
-	dims*=float(72/25.4);
+	dims*=double(72/25.4);
 	
 #if KDE_VERSION > 220
 	if (prn->orientation() != KPrinter::Portrait)
@@ -201,6 +218,7 @@ printImageDialog::pageDimensions()
 	if (prn->orientation() != QPrinter::Portrait)
 		dims.transpose();
 #endif
+#endif//!win
 	
 	return(QRect(QPoint(0,0), dims));
 }
