@@ -13,14 +13,26 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #include "qtfileicondrag.h"
 
 QtFileIconDrag::QtFileIconDrag( QWidget * dragSource, const char* name )
     : QIconDrag( dragSource, name )
-{
-}
+{}
 
 const char*
 QtFileIconDrag::format( int i ) const
@@ -38,7 +50,7 @@ QtFileIconDrag::encodedData( const char* mime ) const
 {
 	QByteArray a;
 	if ( QString( mime ) == "application/x-qiconlist" )
-    {
+	{
 		a = QIconDrag::encodedData( mime );
 	}
 	else if ( QString( mime ) == "text/uri-list" )
@@ -46,15 +58,16 @@ QtFileIconDrag::encodedData( const char* mime ) const
 		QString s = urls.join( "\r\n" );
 		a.resize( s.length() );
 		memcpy( a.data(), s.latin1(), s.length() );
-    }
+	}
 	return a;
 }
 
 bool
 QtFileIconDrag::canDecode( QMimeSource* e )
 {
-	return e->provides( "application/x-qiconlist" ) ||
-	e->provides( "text/uri-list" );
+	return e->provides( 
+		"application/x-qiconlist" ) ||
+		e->provides( "text/uri-list" );
 }
 
 void
@@ -65,5 +78,4 @@ QtFileIconDrag::append( const QIconDragItem &item, const QRect &pr,
     urls << url;
 }
 
-
 #include "qtfileicondrag.moc"
