@@ -13,41 +13,65 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #ifndef __RENAMESERIES_H__
 #define __RENAMESERIES_H__
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+// Qt
 #include <qvariant.h>
 #include <qspinbox.h>
 
+// KDE
 #include <kdatepicker.h>
-#include <kdialog.h>
+#include <kdialogbase.h>
 
-#include "batchrenamer.h"
+class BatchRenamer;
+class ProgressDialog;
+
+class QPopupMenu;
 
 class QVBoxLayout;
 class QHBoxLayout;
 class QGridLayout;
-class KDateWidget;
-class QButtonGroup;
-class QCheckBox;
-class QFrame;
+class QSpacerItem;
 class QGroupBox;
 class QLabel;
+class QSpinBox;
 class QLineEdit;
+class QPushButton;
+class QCheckBox;
+class QButtonGroup;
+class QRadioButton;
+class KDateWidget;
+class QFrame;
 class QListView;
 class QListViewItem;
-class QPushButton;
-class QRadioButton;
-class QSpinBox;
 class QToolButton;
 
 class KCompletion;
 class KLineEdit;
+class KConfig;
 
 
-class RenameSeries : public KDialog
+class RenameSeries : public KDialogBase
 {
     Q_OBJECT
 
@@ -55,28 +79,41 @@ public:
     /**
     	construct a dialog to rename in series files
     */
-    RenameSeries( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+    RenameSeries( QWidget* parent = 0, const char* name = 0 );
     ~RenameSeries();
 
     /**
     	@param filename a file to add for rename
     */
-    void addFile(QString filename);
-    
+    void addFile(const QString& filename);
+
     /**
     	re-init all data
     */
     void clear();
     int exec ();
-    
+
+    void setDateFormat(const QString& format);
+    QString getDateFormat();
+    void setTimeFormat(const QString& format);
+    QString getTimeFormat();
+
+    void writeConfig(KConfig *config, const QString& group);
+    void readConfig(KConfig *config, const QString& group);
 
 public slots:
-        void accept();
+    void slotOk();
 
+    
 protected:
-    QString getPath( QString fn );
+    QString getPath( const QString& fn );
     bool checkErrors(bool checkDir=true);
 
+    QPopupMenu *EXIFpopup;
+
+    BatchRenamer *m_batchRenamer;
+    ProgressDialog *m_progressDialog;
+
     QListViewItem *last;
     QMemArray<QString*> arrayNames;
     int taille;
@@ -85,14 +122,16 @@ protected:
     QListViewItem* currentItem;
     QPixmap *pix;
 
-     QGroupBox* GroupBox1;
-    QLabel* TextLabel1;
-    QCheckBox* checkExtension;
-    QCheckBox* overwrite;
-    QLineEdit* paternLineEdit;
+protected:
+    QGroupBox* GroupBox1;
     QGroupBox* GroupBox9;
     QLabel* TextLabel2_2;
     QSpinBox* spinIndex;
+    QGroupBox* groupBox4;
+    QLineEdit* paternLineEdit;
+    QPushButton* EXIFButton;
+    QCheckBox* overwrite;
+    QCheckBox* checkExtension;
     QButtonGroup* ButtonGroup1;
     QRadioButton* optionCopy;
     QRadioButton* optionMove;
@@ -103,33 +142,27 @@ protected:
     QCheckBox* CheckBox7;
     KDateWidget* kDatePicker;
     QFrame* Line2;
-    QLabel* TextLabel2;
+    QGroupBox* groupBox5;
     QListView* remanedPreviewListView;
     QToolButton* moveUpPushButton;
     QToolButton* moveDownPushButton;
     QCheckBox* previewCheckBox;
-    QLabel* PixmapLabel1;
-    QPushButton* renamePushButton;
-    QPushButton* cancelPushButton;
+    QLabel* PixmapLabel;
 
-protected:
-    QVBoxLayout* RenameSeriesLayout;
-    QHBoxLayout* GroupBox1Layout;
-    QVBoxLayout* layout13;
-    QGridLayout* layout11;
+    QGridLayout* RenameSeriesLayout;
+    QGridLayout* GroupBox1Layout;
     QHBoxLayout* GroupBox9Layout;
-    QHBoxLayout* Layout1;
-    QVBoxLayout* ButtonGroup1Layout;
-    QGridLayout* layout5;
+    QSpacerItem* spacer12;
+    QGridLayout* groupBox4Layout;
+    QGridLayout* ButtonGroup1Layout;
     QVBoxLayout* GroupBox5Layout;
-    QVBoxLayout* layout14;
-    QHBoxLayout* layout13_2;
-    QVBoxLayout* layout7;
+    QVBoxLayout* groupBox5Layout;
+    QHBoxLayout* layout13;
     QVBoxLayout* layout12;
     QVBoxLayout* layout15;
-    QHBoxLayout* layout14_2;
-    QHBoxLayout* layout2;
-
+    QHBoxLayout* layout14_3;
+    QSpacerItem* spacer6_3;
+    QSpacerItem* spacer4_3;
 
 
 protected slots:
@@ -139,10 +172,13 @@ protected slots:
     virtual void slotMoveUp();
     virtual void slotSetImagePreview(int);
     virtual void slotUpdatePreview(QListViewItem*);
-    virtual void slotUpdateRenamed(const QString &);
+    virtual void slotUpdateRenamed(const QString&);
     virtual void slotUpdateRenamed();
 
     void chooseDir();
+
+    void EXIFButtonClicked();
+    void EXIFpopupMenuClicked(int pos);
 };
 
 #endif 
