@@ -13,15 +13,29 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
+ *   USA.                                                                  *
+ *                                                                         *
+ *   For license exceptions see LICENSE.EXC file, attached with the source *
+ *   code.                                                                 *
+ *                                                                         *
  ***************************************************************************/
 
 #include "zipfile.h"
 
 #include <stdlib.h>
 
+// KDE 
 #include <kdebug.h>
 
-ZipFile::ZipFile (QString archive, QString file)
+ZipFile::ZipFile (const QString& archive, const QString& file)
 {
 	this->archive =archive;
 	this->file = file;
@@ -56,7 +70,6 @@ ZipFile::size ()
 bool
 ZipFile::deleteFile ()
 {
-	kdDebug() << __FILE__ << __LINE__ << " ZipFile::deleteFile ()" << endl;
 	QString com=QString(" zip -d  \"%1\" \"%2\"")
 			.arg(archive)
 			.arg(file);
@@ -64,11 +77,9 @@ ZipFile::deleteFile ()
 	connect (proc, SIGNAL (receivedStdout (KProcess *, char *, int)), this,
 	         SLOT (slotMsgRcv (KProcess *, char *, int)));
 
-	kdDebug() << __FILE__ << __LINE__ << " \tZipFile::deleteFile ()\n\tcom=" << com <<endl;
 	*proc << com;
 	proc->start (KShellProcess::Block);   
 
-	kdDebug() << __FILE__ << __LINE__ << " ZipFile::deleteFile ()" << endl;
 	return true;
 }
 
@@ -76,7 +87,6 @@ void
 ZipFile::slotMsgRcv (KProcess * , char *buffer, int buflen)
 {
 	mystdout = new QCString (buffer, buflen);
-	kdDebug() << __FILE__ << __LINE__ << " ZipFile::slotMsgRcv (KProcess * , char *buffer, int buflen)\n\t mystdout = " << mystdout << endl;
 }
 
 #include "zipfile.moc"
